import { AvatarDriveEvent } from '../base/const';
import Amaz = effect.Amaz;
import EventHandler from '../base/event-handler';
/**
 * @class
 * @category Algorithm
 * @name AvatarDrive
 * @classdesc An AvatarDrive class provides capabilities to detect blendshape for 3D face expressions.
 * The definition and usage of blendshape is aligned with Apple ARkit.
 * @description Constructor to create a AvatarDrive instance.
 * @augments EventHandler
 * @sdk 9.8.0
 */
/**
 * @event AvatarDrive#detected
 * @description Fire when a AvatarDrive is detected.
 * @param {number} id - ID of the detected AvatarDrive.
 * @example
 * // use event enum
 * amg.AvatarDrive.on(amg.AvatarDriveEvent.Detected, function(id){
 *   console.log("Start tracking AvatarDrive: " + id);
 * })
 *
 * // use event string
 * amg.AvatarDrive.on('detected', function(id){
 *   console.log("Start tracking AvatarDrive: " + id);
 * })
 * @sdk 9.8.0
 */
/**
 * @event AvatarDrive#lost
 * @description Fire when a AvatarDrive loses tracking state.
 * @param {number} id - ID of the AvatarDrive which loses tracking.
 * @example
 * // use event enum
 * amg.AvatarDrive.on(amg.AvatarDriveEvent.Lost, function(id){
 *   console.log("Lose tracking AvatarDrive: " + id);
 * })
 *
 * // use event string
 * amg.AvatarDrive.on('lost', function(id){
 *   console.log("Lose tracking AvatarDrive: " + id);
 * })
 * @sdk 9.8.0
 */
export default class AvatarDrive extends EventHandler {
    private static _instance;
    private _AvatarDriveProvider;
    faces: Array<AvatarDriveData>;
    static getInstance(): AvatarDrive;
    /**
     * @name AvatarDrive#faces
     * @type {AvatarDriveData[]}
     * @description The {@link AvatarDrive} array, currently support 1 face.
     * @readonly
     * @static
     */
    static get faces(): AvatarDriveData[];
    /**
     * @function
     * @name AvatarDrive.on
     * @description Attach an event handler to an event with the specified name.
     * @param {AvatarDriveEvent} event
     * @param {any} callback
     * @returns {EventHandler} This instance for chaining.
     * @static
     */
    static on(event: AvatarDriveEvent, callback: any, scope?: any): EventHandler;
    /**
     * @function
     * @name AvatarDrive.off
     * @description Detach an event with a specific name, if there is no name provided, all the events are detached.
     * @param {AvatarDriveEvent} event
     * @param {any} callback
     * @returns {EventHandler} This instance for chaining.
     * @static
     */
    static off(event: AvatarDriveEvent, callback: any, scope?: any): EventHandler;
    private constructor();
    onUpdate(): void;
    init(): void;
    setAvatarDriveState(hasFace: boolean, id: number): void;
}
/**
 * @class
 * @category Algorithm
 * @name AvatarDriveData
 * @classdesc A AvatarDriveData class stores the channels data of AvatarDriveData, isTracking and id of face.
 * @description Constructor to create a AvatarDriveData instance.
 */
declare class AvatarDriveData {
    _avatarDriveInfo: Amaz.AvatarDriveInfoInterface | null;
    constructor();
    /**
     * @name AvatarDriveData#id
     * @description The algorithm detects the corresponding ID of the AvatarDrive face.
     * @type {number}
     * @readonly
     */
    get id(): number;
    /**
     * @name AvatarDriveData#isTracking
     * @description Returns whether successfully tracking a face or not.
     * @type {boolean}
     * @readonly
     */
    get isTracking(): boolean;
    /**
     * @name AvatarDriveData#channels
     * @description Returns expression blendshape factor, blendshape definition is the same as Apple ARkit, total of 52 blendshapes.
     * @type {FloatVector}
     * @readonly
     */
    get channels(): Amaz.FloatVector;
}
export {};
