import { BodyEvent } from '../base/const';
import Amaz = effect.Amaz;
import EventHandler from '../base/event-handler';
import Rect from '../math/rect';
/**
 * @class
 * @category Algorithm
 * @name Body2D
 * @classdesc A Body2D class provides capabilities to detect 2D
 * skeletal keypoints from the human body.
 * @description Constructor to create a Body2D instance.
 * @augments EventHandler
 * @sdk 9.8.0
 */
/**
 * @event Body2D#detected
 * @description Fire when a body is detected.
 * @param {number} id - ID of the detected body.
 * @example
 * // use event enum
 * amg.Body2D.on(amg.BodyEvent.Detected, function(id){
 *   console.log("Start tracking body: " + id);
 * })
 *
 * // use event string
 * amg.Body2D.on('detected', function(id){
 *   console.log("Start tracking body: " + id);
 * })
 * @sdk 9.8.0
 */
/**
 * @event Body2D#lost
 * @description Fire when a body loses tracking state.
 * @param {number} id - ID of the body which loses tracking.
 * @example
 * // use event enum
 * amg.Body2D.on(amg.BodyEvent.Lost, function(id){
 *   console.log("Lose tracking body: " + id);
 * })
 *
 * // use event string
 * amg.Body2D.on('lost', function(id){
 *   console.log("Lose tracking body: " + id);
 * })
 * @sdk 9.8.0
 */
/**
 * @event Body2D#action
 * @description Fire when a body action recognized or changed.
 * @param {number} id - ID of the body that has recognized a new action or change in action.
 * @param {number} BodyAction - Action label recognized.
 * @example
 * // use event enum
 * amg.Body2D.on(amg.BodyEvent.Action, function(action, id){
 *   console.log("Detected body action from " + id + " action label is: " + action) ;
 * })
 *
 * // use event string
 * amg.Body2D.on('action', function(action, id){
 *   console.log("Detected body action from " + id + " action label is: " + action) ;
 * })
 * @sdk 9.8.0
 */
export default class Body2D extends EventHandler {
    private static _instance;
    private _body2dProvider;
    bodies: Array<Body2dData>;
    static getInstance(): Body2D;
    /**
     * @name Body2D#bodies
     * @type {Body2dData[]}
     * @description The {@link Body2dData} array with maximum 2 bodies supported. Bodies[0] is the first body the algorithm detected.
     * @readonly
     * @static
     */
    static get bodies(): Body2dData[];
    /**
     * @function
     * @name Body2D.on
     * @description Attach an event handler to an event with the specified name.
     * @param {BodyEvent} event
     * @param {any} callback
     * @returns {EventHandler} This instance for chaining.
     * @static
     */
    static on(event: BodyEvent, callback: any, scope?: any): EventHandler;
    /**
     * @function
     * @name Body2D.off
     * @description Detach an event with a specific name, if there is no name provided, all the events are detached.
     * @param {BodyEvent} event
     * @param {any} callback
     * @returns {EventHandler} This instance for chaining.
     * @static
     */
    static off(event: BodyEvent, callback: any, scope?: any): EventHandler;
    private constructor();
    onUpdate(): void;
    init(): void;
    setBodyState(hasBody: boolean, id: number): void;
    setBodyActionState(id: number, BodyAction: number): void;
}
/**
 * @class
 * @category Algorithm
 * @name Body2dData
 * @classdesc A Body2dData class stores the joints data of body2d including position, rotation and score.
 * @description Constructor to create a Body2dData instance.
 */
declare class Body2dData {
    _skeletonInfo: Amaz.SkeletonInfoInterface | null;
    _actionRecognitionInfo: Amaz.ActionRecognitionInfoInterface | null;
    constructor();
    /**
     * @name Body2dData#rect
     * @description The normalized human body area rectangle, in the range of [0.5-1], needs to be converted if it is to be used in screen space.
     * @type {Rect}
     * @readonly
     */
    get rect(): Rect;
    /**
     * @name Body2dData#id
     * @description The algorithm detects the corresponding ID of the human body.
     * @type {number}
     * @readonly
     */
    get id(): number;
    /**
     * @name Body2dData#keyPointDetected
     * @description Returns whether each keypoint is detected or not, using the index access result of the corresponding keypoint. If not detected then the value is 0.
     * @type {UInt8Vector}
     * @readonly
     */
    get keyPointDetected(): Amaz.UInt8Vector;
    /**
     * @name Body2dData#keyPointsScore
     * @description Returns the confidence value of each key point in the range of [0-1], using the index of the corresponding key point to access the result.
     * @type {FloatVector}
     * @readonly
     */
    get keyPointsScore(): Amaz.FloatVector;
    /**
     * @name Body2dData#keyPoints
     * @description The normalized 2D keypoint coordinates are in the range [0.5-1] and need to be converted if they are to be used in screen space.
     * @type {Vec2Vector}
     * @readonly
     */
    get keyPoints(): Amaz.Vec2Vector;
    /**
     * @name Body2dData#isActionValid
     * @description Return true if it successfully detects the action to this body.
     * @type {boolean}
     * @readonly
     */
    get isActionValid(): boolean;
    /**
     * @name Body2dData#actionLabel
     * @description Action index recognized by the algorithm, depending on action_recognition_tmpl.
     * @type {number}
     * @readonly
     */
    get actionLabel(): number;
    /**
     * @name Body2dData#actionScore
     * @description Confidence level of the action recognition results.
     * @type {number}
     * @readonly
     */
    get actionScore(): number;
}
export {};
