import { BodyEvent } from '../base/const';
import Amaz = effect.Amaz;
import EventHandler from '../base/event-handler';
import Vec3 from '../math/vec3';
/**
 * @class
 * @category Algorithm
 * @name Body3D
 * @classdesc A Body3D class provides capabilities to detect
 * Avatar3D joint points from the human body.
 * @description Constructor to create a Body3D instance.
 * @augments EventHandler
 * @sdk 9.8.0
 */
/**
 * @event Body3D#detected
 * @description Fire when a body is detected.
 * @param {number} id - ID of the detected body.
 * @example
 * // use event enum
 * amg.Body3D.on(amg.BodyEvent.Detected, function(id){
 *   console.log("Start tracking body: " + id);
 * })
 *
 * // use event string
 * amg.Body3D.on('detected', function(id){
 *   console.log("Start tracking body: " + id);
 * })
 * @sdk 9.8.0
 */
/**
 * @event Body3D#lost
 * @description Fire when a body loses tracking state.
 * @param {number} id - ID of the body which loses tracking.
 * @example
 * // use event enum
 * amg.Body3D.on(amg.BodyEvent.Lost, function(id){
 *   console.log("Lose tracking body: " + id);
 * })
 *
 * // use event string
 * amg.Body3D.on('lost', function(id){
 *   console.log("Lose tracking body: " + id);
 * })
 * @sdk 9.8.0
 */
export default class Body3D extends EventHandler {
    private static _instance;
    private _Body3dProvider;
    bodies: Array<Body3dData>;
    _trackingMode: boolean;
    static getInstance(): Body3D;
    /**
     * @name Body3D#bodies
     * @type {Body3dData[]}
     * @description The {@link Body3dData} array with maximum 2 bodies supported. Bodies[0] is the first body the algorithm detected.
     * @readonly
     * @static
     */
    static get bodies(): Body3dData[];
    /**
     * @function
     * @name Body3D.on
     * @description Attach an event handler to an event with the specified name.
     * @param {BodyEvent} event
     * @param {any} callback
     * @returns {EventHandler} This instance for chaining.
     * @static
     */
    static on(event: BodyEvent, callback: any, scope?: any): EventHandler;
    /**
     * @function
     * @name Body3D.off
     * @description Detach an event with a specific name, if there is no name provided, all the events are detached.
     * @param {BodyEvent} event
     * @param {any} callback
     * @returns {EventHandler} This instance for chaining.
     * @static
     */
    static off(event: BodyEvent, callback: any, scope?: any): EventHandler;
    /**
     * @name Body3D#trackingMode
     * @type {boolean}
     * @description Return avatar3d algorithm tracking mode.
     * @readonly
     * @static
     */
    static get trackingMode(): boolean;
    private constructor();
    onUpdate(): void;
    init(): void;
    setBodyState(hasBody: boolean, id: number): void;
}
/**
 * @class
 * @category Algorithm
 * @name Body3dData
 * @classdesc A Body2dData class stores the joints data of body3d including position, rotation, camera fov and algorithm image size.
 * @description Constructor to create a new Body3dData instance.
 */
declare class Body3dData {
    _avatar3DInfo: Amaz.Avatar3DInfoInterface | null;
    constructor();
    /**
     * @name Body3dData#id
     * @description The algorithm detects the corresponding ID of the human body.
     * @type {number}
     * @readonly
     */
    get id(): number;
    /**
     * @name Body3dData#root
     * @description The 3D coordinates of the root node, which is amg.Body3DKeyPointType.Pelvis .
     * @type {Vec3}
     * @readonly
     */
    get root(): Vec3;
    /**
     * @name Body3dData#focalLength
     * @description Focal length is used to calculate and adjust the relevant parameters of the camera in the scene.
     * @type {number}
     * @readonly
     */
    get focalLength(): number;
    /**
     * @name Body3dData#isDetected
     * @description Return whether the body is detected or not.
     * @type {boolean}
     * @readonly
     */
    get isDetected(): boolean;
    /**
     * @name Body3dData#jointRotations
     * @description Returns the vector of quaternions on the 24 joints corresponding to the Body3DKeyPointType.
     * @type {Amaz.QuatVector}
     * @readonly
     */
    get jointRotations(): Amaz.QuatVector;
    /**
     * @name Body3dData#jointPositions
     * @description Returns the vector of positions on the 24 joints corresponding to the Body3DKeyPointType.
     * @type {Amaz.Vec3Vector}
     * @readonly
     */
    get jointPositions(): Amaz.Vec3Vector;
    /**
     * @name Body3dData#imageHeight
     * @description Return the image height of the avatar3d algorithm.
     * @type {number}
     * @readonly
     */
    get imageHeight(): number;
    /**
     * @name Body3dData#imageWidth
     * @description Return the image width of the avatar3d algorithm.
     * @type {number}
     * @readonly
     */
    get imageWidth(): number;
}
export {};
