import { HandDynamicGesture, HandEvent, HandKeyPoint, HandStaticGesture } from '../base/const';
import Amaz = effect.Amaz;
import EventHandler from '../base/event-handler';
import Vec3 from '../math/vec3';
import Vec2 from '../math/vec2';
/**
 * @class
 * @category Algorithm
 * @name Hand
 * @classdesc A Hand class provides capabilities for hand tracking,
 * gesture recognition, 2D keypoint tracking, 3D keypoint tracking, etc.
 * @description Constructor to create a Hand instance.
 * @augments EventHandler
 * @sdk 9.8.0
 */
/**
 * @event Hand#detected
 * @description Fire when a hand is detected.
 * @param {number} id - ID of the detected hand.
 * @example
 * // use event enum
 * amg.Hand.on(amg.HandEvent.Detected, function(id){
 *   console.log("Start tracking hand: " + id);
 * })
 *
 * // use event string
 * amg.Hand.on('detected', function(id){
 *   console.log("Start tracking hand: " + id);
 * })
 * @sdk 9.8.0
 */
/**
 * @event Hand#lost
 * @description Fire when a hand lose tracking state.
 * @param {number} id - ID of the hand which lose tracking.
 * @example
 * // use event enum
 * amg.Hand.on(amg.HandEvent.Lost, function(id){
 *   console.log("Lose tracking hand: " + id);
 * })
 *
 * // use event string
 * amg.Hand.on('lost', function(id){
 *   console.log("Lose tracking hand: " + id);
 * })
 * @sdk 9.8.0
 */
/**
 * @event Hand#staticgesture
 * @description Fire when a hand static gesture is detected or changed.
 * @param {number} id - ID of the hand which static gesture is detected or changed.
 * @param {HandDynamicGesture} action - Action detected.
 * @example
 * // use event enum
 * amg.Hand.on(amg.HandEvent.StaticGesture, function(id, action){
 *   console.log("Detected hand static action from " + id + " action is: " + action) ;
 * })
 *
 * // use event string
 * amg.Hand.on('staticgesture', function(id, action){
 *   console.log("Detected hand static action from " + id + " action is: " + action) ;
 * })
 * @sdk 9.8.0
 */
/**
 * @event Hand#dynamicgesture
 * @description Fire when a hand dynamic gesture is detected or changed.
 * @param {number} id - ID of the hand which dynamic gesture is detected or changed
 * @param {HandDynamicGesture} action - Action detected.
 * @example
 * // use event enum
 * amg.Hand.on(amg.HandEvent.DynamicGesture, function(id, action){
 *   console.log("Detected hand dynamic action from " + id + " action is: " + action) ;
 * })
 *
 * // use event string
 * amg.Hand.on('dynamicgesture', function(id, action){
 *   console.log("Detected hand dynamic action from " + id + " action is: " + action) ;
 * })
 * @sdk 9.8.0
 */
export default class Hand extends EventHandler {
    private static _instance;
    private _handProvider;
    hands: Array<HandData>;
    static getInstance(): Hand;
    /**
     * @name Hand#hands
     * @type {HandData[]}
     * @description The {@link HandData} array with maximum 2 hands supported. hands[0] is the first hand the algorithm detected.
     * @readonly
     * @static
     */
    static get hands(): Array<HandData>;
    /**
     * @function
     * @name Hand.on
     * @description Attach an event handler to an event with the specified name.
     * @param {HandEvent} event
     * @param {any} callback
     * @returns {EventHandler} This instance for chaining.
     * @static
     */
    static on(event: HandEvent, callback: any, scope?: any): EventHandler;
    /**
     * @function
     * @name Hand.off
     * @description Detach an event with a specific name, if there is no name provided, all the events are detached.
     * @param {HandEvent} event
     * @param {any} callback
     * @returns {EventHandler} This instance for chaining.
     * @static
     */
    static off(event: HandEvent, callback: any, scope?: any): EventHandler;
    private constructor();
    onUpdate(): void;
    init(): void;
    setHandState(hasHand: boolean, id: number): void;
    setHandActionState(id: number, action: HandStaticGesture): void;
    setHandSeqActionState(id: number, action: HandDynamicGesture): void;
}
/**
 * @class
 * @category Algorithm
 * @name HandData
 * @classdesc A HandData class stores hand algorithm result including tracking points information, scale, rotation, left or right hand and gestures.
 * @description Constructor to create a new HandData instance.
 */
declare class HandData {
    _handInfo: Amaz.HandInfoInterface | null;
    constructor();
    /**
     * @function
     * @name HandData#getKeyPoint2D
     * @description Returns a key point 2D position (screen space).
     * @param {HandKeyPoint} keyPoint - The key point that will return result.
     * @returns {Vec2} 2D key point coordinates.
     * @readonly
     */
    getKeyPoint2D(keyPoint: HandKeyPoint): Vec2 | null;
    /**
     * @function
     * @name HandData#getKeyPointOffset3D
     * @description Returns the 3D offset value of the specified keypoint relative to amg.HandKeyPoint.Middle3, with data in the range [-1~1]. The position of Middle3 is always (0, 0, 0) and the amg.HandKeyPoint.center is not available.
     * @param {HandKeyPoint} keyPoint - The key point that will return result.
     * @returns {Vec3} Key point offset in 3D position.
     * @readonly
     */
    getKeyPointOffset3D(keyPoint: HandKeyPoint): Vec3 | null;
    /**
     * @name HandData#isLeftProbability
     * @description Returns the possibility that the hand being tracked is the left hand. Since the front camera of the phone captures the mirror image, the algorithm results of the front and back cameras will have opposite results.
     * @type {number}
     * @readonly
     */
    get isLeftProbability(): number;
    /**
     * @name HandData#isLeft
     * @description Returns whether the tracked hand is left-handed or not. On some machines, the algorithm results converge slowly and the result is unstable.
     * @type {boolean}
     * @readonly
     */
    get isLeft(): boolean;
    /**
     * @name HandData#id
     * @description The tracked hand ID.
     * @type {number}
     * @readonly
     */
    get id(): number;
    /**
     * @name HandData#scale
     * @description The scaling value of the returned hand, which is related to the resolution, needs to be normalized to the resolution before being used.
     * @type {number}
     * @readonly
     */
    get scale(): number;
    /**
     * @name HandData#rotation
     * @description Rotation around the z-axis, in the range of [-180~180].
     * @type {number}
     * @readonly
     */
    get rotation(): number;
    /**
     * @name HandData#staticGesture
     * @description Current static gesture.
     * @type {HandStaticGesture}
     * @readonly
     */
    get staticGesture(): HandStaticGesture;
    /**
     * @name HandData#dynamicGesture
     * @description Current dynamic gesture.
     * @type {HandDynamicGesture}
     * @readonly
     */
    get dynamicGesture(): HandDynamicGesture;
}
export {};
