import Amaz = effect.Amaz;
import Rect from '../../math/rect';
import Mat4 from '../../math/mat4';
import { FaceAction, FaceExpression, FaceLandmarkType, FacePart, FaceType } from '../../base/const';
import { FaceMeshInfo } from './types';
/**
 * @class
 * @category Algorithm
 * @name FaceData
 * @classdesc A FaceData class stores head algorithm result including credibility score, transform, face index, yaw, pitch, roll, face rect and expression.
 * @description Constructor to create a new FaceData instance.
 */
export default abstract class FaceData {
    type: FaceType;
    score: number;
    id: number;
    yaw: number;
    pitch: number;
    roll: number;
    transform: Mat4;
    rect: Rect;
    expression: FaceExpression;
    faceMesh: FaceMeshInfo;
    isValidFace: boolean;
    action: FaceAction;
    contour: Amaz.Vec2Vector;
    landmarks106: Amaz.Vec2Vector;
    landmarks240EyeLeft: Amaz.Vec2Vector;
    landmarks240EyeRight: Amaz.Vec2Vector;
    landmarks240EyebrowLeft: Amaz.Vec2Vector;
    landmarks240EyebrowRight: Amaz.Vec2Vector;
    landmarks240Lip: Amaz.Vec2Vector;
    landmarks280LeftIris: Amaz.Vec2Vector;
    landmarks280RightIris: Amaz.Vec2Vector;
    landmarks3d: Amaz.Vec3Vector;
    landmarksPetV2: Amaz.Vec2Vector;
    /**
     * @name FaceData#type
     * @description The tracked face type.
     * @type {FaceType}
     * @readonly
     */
    /**
     * @name FaceData#id
     * @description The tracked face id.
     * @type {number}
     * @readonly
     */
    /**
     * @name FaceData#score
     * @description Get credibility score for face detection, in the range of [0,1].
     * @type {number}
     * @readonly
     */
    /**
     * @name FaceData#transform
     * @description Face transform of the tracked face.
     * @type {Mat4}
     * @readonly
     */
    /**
     * @name FaceData#yaw
     * @description The yaw of the tracked face. (Radius)
     * @type {number}
     * @readonly
     */
    /**
     * @name FaceData#pitch
     * @description The pitch of the tracked face. (Radius)
     * @type {number}
     * @readonly
     */
    /**
     * @name FaceData#roll
     * @description The roll of the tracked face. (Radius)
     * @type {number}
     * @readonly
     */
    /**
     * @name FaceData#rect
     * @description The rectangle of the tracked face.
     * @type {Rect}
     * @readonly
     */
    /**
     * @name FaceData#expression
     * @description Get expression of the tracked face.
     * @type {FaceExpression}
     * @readonly
     */
    constructor();
    /**
     * @function
     * @name FaceData.isValid
     * @returns {boolean}
     * @description Check if the face data is valid or not.
     * @static
     */
    isValid(): boolean;
    /**
     * @function
     * @name FaceData.hasAction
     * @returns {boolean}
     * @description Check if there is any action of the tracked face.
     * @static
     */
    hasAction(): boolean;
    /**
     * @function
     * @name FaceData#getLandmarks
     * @returns {Vec2Vector | Vec3Vector} The 2d or 3d landmarks of the specific face.
     * @param {FacePart} facePart
     * @param {FaceLandmarkType} faceLandmarkType Face106/Face240/Face280. If Face280 for facePart is not implemented, it will fall back to Face240, and so on.
     * @description Get the landmarks of the specific face. When the intended faceLandmarkType for a facePart is not implemented, it will fall back to a default one.
     * @static
     */
    abstract getLandmarks(facePart: FacePart, faceLandmarkType?: FaceLandmarkType): any;
    protected getPartLandmark(facePart: FacePart, wholeLandmarks: Amaz.Vec2Vector, facePartMap: Map<FacePart, number[][]>): Amaz.Vec2Vector | null;
    protected facePartHelper(start: number, end: number, wholeLandmarks: Amaz.Vec2Vector, partLandmarks: Amaz.Vec2Vector): any;
}
