import { FaceEvent, FaceLandmarkType, FacePart, FaceType } from '../../base/const';
import EventHandler from '../../base/event-handler';
import FaceData from './face-data';
/**
 * @class
 * @category Algorithm
 * @name Head
 * @classdesc A Head class provides capabilities for head tracking,
 * expression recognition, 2D keypoint tracking, 3D keypoint tracking, etc.
 * @description Constructor to create a Head instance.
 * @augments EventHandler
 * @sdk 9.8.0
 */
/**
 * @event Head#detected
 * @description Fire when a head is detected.
 * @param {number} id - ID of the detected head.
 * @example
 * // use event enum
 * amg.Head.on(amg.FaceEvent.Detected, function(id, type){
 *   console.log('Start tracking head: ' + id + ' ' + type);
 * })
 *
 * // use event string
 * amg.Head.on('detected', function(id){
 *   console.log('Start tracking head: ' + id + ' ' + type);
 * })
 * @sdk 9.8.0
 */
/**
 * @event Head#lost
 * @description Fire when a head lose tracking state.
 * @param {number} id - ID of the head which lose tracking.
 * @example
 * // use event enum
 * amg.Head.on(amg.FaceEvent.Lost, function(id){
 *   console.log("Lose tracking head: " + id);
 * })
 *
 * // use event string
 * amg.Head.on('lost', function(id){
 *   console.log("Lose tracking head: " + id);
 * })
 * @sdk 9.8.0
 */
export default class Head extends EventHandler {
    private static _instance;
    private _faceProviders;
    faces: Array<FaceData>;
    hasFaceMap: Map<FaceType, Map<number, boolean>>;
    static getInstance(): Head;
    /**
     * @name Head#faces
     * @type {FaceData[]}
     * @description The {@link FaceData} array with maximum 5 heads supported. heads[0] is the first face the algorithm detected.
     */
    private constructor();
    /**
     * @function
     * @name Head.getLandmark
     * @description Get the landmarks of the specific face.
     * @param {FacePart} part
     * @param {number} id
     * @param {FaceLandmarkType} option
     * @returns {Vec2Vector | Vec3Vector} The 2d or 3d landmarks of the specific face.
     * @static
     */
    static getLandmark(part: FacePart, id: number, option: FaceLandmarkType): any;
    getLandmarks(part: FacePart, index: number, option: FaceLandmarkType): any;
    onUpdate(): void;
    init(): void;
    private resetFaceData;
    addFaceData(data: FaceData): void;
    static get faces(): FaceData[];
    /**
     * @function
     * @name Head.getFacesByType
     * @description Get an array of {@link FaceData} with a specific type of faces.
     * @param {FaceType} type
     * @returns {Array<FaceData>} An array of faces with type. If there are no face with the type, return an empty Array.
     * @static
     */
    static getFacesByType(type: FaceType): Array<FaceData>;
    /**
     * @function
     * @name Head.on
     * @type {EventHandler}
     * @description Attach an event handler to an event with the specified name.
     * @param {FaceEvent} event
     * @param {any} callback
     * @returns {EventHandler} This instance for chaining.
     * @static
     */
    static on(event: FaceEvent, callback: any, scope?: any): EventHandler;
    /**
     * @function
     * @name Head.off
     * @type {EventHandler}
     * @description Detach an event with a specific name, if there is no name provided, all the events are detached.
     * @param {FaceEvent} event
     * @param {any} callback
     * @returns {EventHandler} This instance for chaining.
     * @static
     */
    static off(event: FaceEvent, callback: any, scope?: any): EventHandler;
    setFaceState(hasFace: boolean, id: number, faceType: FaceType): void;
}
