import Amaz = effect.Amaz;
import Vec2 from '../math/vec2';
import Vec3 from '../math/vec3';
import Vec4 from '../math/vec4';
import Mat4 from '../math/mat4';
import Color from '../math/color';
import Texture from './texture';
import XShader from './xshader';
/**
 * @type {Vec2 | Vec3 | Vec4 | Mat4 | Color | Amaz.Texture | Texture | undefined}
 * @name attributeTypes
 * @description Possible type of shader attributes.
 * @sdk 9.8.0
 */
declare type UniformTypes = number | Vec2 | Vec3 | Vec4 | Mat4 | Color | Amaz.Texture | Texture | undefined;
/**
 * @interface
 * @name MaterialData
 * @description Material data used to create material.
 * @sdk 9.8.0
 */
export interface MaterialData {
    native: Amaz.Material;
    shader: XShader;
    uniforms: Map<string, UniformTypes>;
    macros: Map<string, number>;
}
/**
 * @class
 * @category Rendering
 * @name Material
 * @classdesc Material class holds a mesh shader, uniforms, and macros.
 * @description This class is used to represent material in Amazing JS.
 * @sdk 9.8.0
 */
export default class Material {
    /**
     * @function
     * @name Material#initializeProperties
     * @description Initiliazes material properties with native if native is defined.
     * @param {Amaz.Material} native The material native class that holds the properties.
     * @returns {void}
     * @sdk 9.8.0
     */
    private frontNative;
    constructor(matData?: MaterialData | undefined);
    /**
     * @function
     * @name Material#clone
     * @description Clone material to create new one.
     * @returns {Material} Cloned material.
     * @sdk 9.8.0
     */
    clone(): Material;
    /**
     * @function
     * @name Material#setUniform
     * @description Add a uniform used as an uniform in the shader to this material, value could be the type of number, Vec2, Vec3, Vec4, Mat4, Color and Texture.
     * @param {string} name uniform's name.
     * @param { Vec2 | Vec3 | Vec4| Mat4  | Color | Amaz.Texture | Texture | undefined} value  uniform's value from one of the below types.
     * @returns {void}
     * @sdk 9.8.0
     */
    setUniform(name: string, value: UniformTypes): void;
    /**
     * @function
     * @deprecated since version 5.4.0 use setUniform instead
     * @name Material#addProperty
     * @description Set uniform value for material, value could be the type of number, Vec2, Vec3, Vec4, Mat4, Color and Texture.
     * @param {string} name uniform's name.
     * @param { Vec2 | Vec3 | Vec4| Mat4  | Color | Amaz.Texture | Texture | undefined} value  uniform's value from one of the below types.
     * @returns {void}
     * @sdk 9.8.0
     */
    addProperty(name: string, value: UniformTypes): void;
    /**
     * @function
     * @name Material#getUniform
     * @description Get value of uniform in material.
     * @param {string} name Uniform's name.
     * @returns {Vec2 | Vec3 | Vec4| Mat4  | Color | Amaz.Texture | Texture | undefined} Rerturns a value of a uniform. If a uniform does not exist, will return undefined.
     * @sdk 9.8.0
     */
    getUniform(name: string): UniformTypes;
    /**
     * @function
     * @name Material#removeUniform
     * @description Remove uniform.
     * @param {string} name Uniform's name.
     * @sdk 9.8.0
     */
    removeUniform(name: string): void;
    /**
     * @function
     * @name Material#addMacro
     * @description Add macro and its value.
     * @param {string} name Macro's name.
     * @param {number} value Macro's value.
     * @sdk 9.8.0
     */
    addMacro(name: string, value: number): void;
    /**
     * @function
     * @name Material#removeMacro
     * @description Remove macro.
     * @param {string} name Macro's name.
     * @sdk 9.8.0
     */
    removeMacro(name: string): void;
    /**
     * @name Material#native
     * @type {Amaz.Material}
     * @description Amaz.Material (JS RTTI) type of the Material class.
     * @sdk 9.8.0
     */
    native: Amaz.Material;
    /**
     * @name Material#name
     * @type {string}
     * @description Identifier of Material Class.
     * @sdk 9.8.0
     */
    name: string;
    /**
     * @name Material#XShader
     * @type {XShader}
     * @description The XShader class used by the material.
     * @sdk 9.8.0
     */
    set shader(value: XShader);
    /**
     * @name Material#uniforms
     * @type {Map<string, Vec2 | Vec3 | Vec4| Mat4  | Color | Amaz.Texture | Texture | undefined>}
     * @description Uniforms owned by the material
     * @sdk 9.8.0
     */
    uniforms: Map<string, UniformTypes>;
}
export {};
