import { TextureFilterMode, TextureWrapMode, TextureFilterMipMapMode } from './const';
import Amaz = effect.Amaz;
/**
 * @class
 * @category Rendering
 * @name WrapMode
 * @classdesc WrapMode class that represents wrap mode settings of a texture.
 * @description This class is used to represent WrapMode settings.
 * @param {Texture} owner The Texture that owns the wrap mode settings.
 * @param {TextureWrapMode} S Texture wrap mode setting for S dimension.
 * @param {TextureWrapMode} R Texture wrap mode setting for R dimension.
 * @param {TextureWrapMode} T Texture wrap mode setting for T dimension.
 * @sdk 9.8.0
 */
export declare class WrapMode {
    constructor(owner: Texture, horizontal?: TextureWrapMode | undefined, depth?: TextureWrapMode | undefined, vertical?: TextureWrapMode | undefined);
    /**
     * @function
     * @name WrapMode#setUniformWrapMode
     * @description Changes wrap mode of texture S, R, and T dimension.
     * @param {TextureWrapMode} wrap Texture wrap mode.
     * @returns {void}
     * @sdk 9.8.0
     */
    setUniformWrapMode(wrap: TextureWrapMode): void;
    /**
     * @name WrapMode#owner
     * @type {Texture}
     * @description Texture that wrapmode is modified.
     * @sdk 9.8.0
     */
    private owner;
    /**
     * @name WrapMode#horizontal
     * @type {TextureWrapMode}
     * @description Wrap mode of horizontal dimension. This is wrapModeS in JS RTTI.
     * @sdk 9.8.0
     */
    get horizontal(): TextureWrapMode | null;
    set horizontal(horizontal: TextureWrapMode | null);
    /**
     * @name WrapMode#depth
     * @type {TextureWrapMode}
     * @description Wrap mode of depth dimension.This is wrapModeR in JS RTTI.
     * @sdk 9.8.0
     */
    get depth(): TextureWrapMode | null;
    set depth(depth: TextureWrapMode | null);
    /**
     * @name WrapMode#Vertical
     * @type {TextureWrapMode}
     * @description Wrap mode of Vertical dimension.This is wrapModeT in JS RTTI.
     * @sdk 9.8.0
     */
    get vertical(): TextureWrapMode | null;
    set vertical(vertical: TextureWrapMode | null);
}
/**
 * @class
 * @category Rendering
 * @name FilterMode
 * @classdesc FilterMode class that represents filter mode settings of a texture.
 * @description This class is used to represent FilterMode settings.
 * @param {TextureFilterMode} filterMin filter minfication settting.
 * @param {TextureFilterMode} filterMag filter magnification settting.
 * @param {TextureFilterMipMapMode} mipMapFilter mip map filter setting.
 * @sdk 9.8.0
 */
export declare class FilterMode {
    constructor(owner: Texture, filterMin?: TextureFilterMode | undefined, filterMax?: TextureFilterMode | undefined, mipMapFilter?: TextureFilterMipMapMode | undefined);
    /**
     * @name FilterMode#owner
     * @type {Texture}
     * @description Texture that filter mode is modified.
     * @sdk 9.8.0
     */
    private owner;
    /**
     * @name FilterMode#min
     * @type {TextureFilterMode}
     * @description Minification filter setting for texture.
     * @sdk 9.8.0
     */
    get min(): TextureFilterMode | null;
    set min(min: TextureFilterMode | null);
    /**
     * @name FilterMode#mag
     * @type {TextureFilterMode}
     * @description Magnification filter setting for texture.
     * @sdk 9.8.0
     */
    get mag(): TextureFilterMode | null;
    set mag(mag: TextureFilterMode | null);
    /**
     * @name FilterMode#mipMap
     * @type {TextureFilterMipMapMode}
     * @description Mip map filter setting for texture.
     * @sdk 9.8.0
     */
    get mipMap(): TextureFilterMipMapMode | null;
    set mipMap(mipMap: TextureFilterMipMapMode | null);
}
/**
 * @interface
 * @name TextureOptions
 * @description Texture options that users can use to mdoify texture.
 * @sdk 9.8.0
 */
export interface TextureOptions {
    width: number;
    height: number;
    depth: number;
    horizontalWrap: TextureWrapMode;
    verticalWrap: TextureWrapMode;
    depthWrap: TextureWrapMode;
    minFilter: TextureFilterMode;
    magFilter: TextureFilterMode;
    mipMapFilter: TextureFilterMipMapMode;
}
/**
 * @interface
 * @name MaterialData
 * @description Textyre data used to create texture.
 * @sdk 9.8.0
 */
export interface TextureData {
    native: Amaz.Texture;
    path: string;
    options: TextureOptions;
}
/**
 * @class
 * @category Rendering
 * @name Texture
 * @classdesc Texture class is a class for textures used in rendering.
 * @description Texture class that represents Amaz.Texture class in Amazing JS.
 * @param {Amaz.Texture | undefined } native The Amaz.Texture that can be used to intialize Texture class.
 * @param { number } width Width of texture.
 * @param { number } height Height of texture.
 * @param { number } depth Depth of texture.
 * @param { WrapMode } wrapMode Wrap mode of texture.
 * @param { FilterMode } filterMode Filter mode of texture.
 * @sdk 9.8.0
 */
export default class Texture {
    /**
     * @function
     * @name Texture#fromNative
     * @description Initialize Texture class with Amaz.Texture class.
     * @param {Amaz.Texture} native Amaz.Texture used to initialize Texture class.
     * @returns {void}
     * @sdk 9.8.0
     */
    private fromNative;
    /**
     * @function
     * @name Texture#fromOptions
     * @description Adjust texture properties according to texture options.
     * @param {TextureOptions} options Texture settings for this particular texture.
     * @returns {void}
     * @sdk 9.8.0
     */
    private fromOptions;
    constructor(textureData?: TextureData | undefined);
    /**
     * @function
     * @name Texture#getSize
     * @description Get the dimension of a texture.
     * @returns {number} Returns width and height of the texture.
     * @sdk 9.8.0
     */
    getSize(): {
        width: number;
        height: number;
    };
    /**
     * @name Texture#name
     * @type {string}
     * @description Identifier of texture class.
     * @sdk 9.8.0
     */
    name: string;
    /**
     * @name Texture#native
     * @type {Amaz.Texture}
     * @description The Amaz.Texture (JS RTTI) type of the Texture class.
     * @sdk 9.8.0
     */
    native: Amaz.Texture | null;
    /**
     * @name Texture#height
     * @type {number}
     * @description Height of texture.
     * @sdk 9.8.0
     */
    get height(): number;
    set height(height: number);
    /**
     * @name Texture#width
     * @type {number}
     * @description Width of texture.
     * @sdk 9.8.0
     */
    get width(): number;
    set width(width: number);
    /**
     * @name Texture#depth
     * @type {number}
     * @description Depth of texture.
     * @sdk 9.8.0
     */
    get depth(): number;
    set depth(depth: number);
    /**
     * @name Texture#internalFormat
     * @type {Amaz.InternalFormat}
     * @description Internal format of texture.
     * @sdk 9.8.0
     */
    get internalFormat(): Amaz.InternalFormat | null;
    set internalFormat(internalFormat: Amaz.InternalFormat | null);
    /**
     * @name Texture#dataType
     * @type {Amaz.DataType}
     * @description Data type of texture.
     * @sdk 9.8.0
     */
    get dataType(): Amaz.DataType | null;
    set dataType(dataType: Amaz.DataType | null);
    /**
     * @name Texture#enableMipMap
     * @type {boolean}
     * @description Enables or disables mip mapping.
     * @sdk 9.8.0
     */
    get enableMipMap(): boolean | null;
    set enableMipMap(enableMipMap: boolean | null);
    /**
     * @name Texture#builtInType
     * @type {Amaz.BuiltInTextureType}
     * @description Built-in type of texture.
     * @sdk 9.8.0
     */
    get builtinType(): Amaz.BuiltInTextureType | null;
    set builtinType(builtinType: Amaz.BuiltInTextureType | null);
    /**
     * @name Texture#wrapMode
     * @type {WrapMode}
     * @description Wrap mode settings of texture.
     * @sdk 9.8.0
     */
    wrapMode: WrapMode;
    /**
     * @name Texture#filterMode
     * @type {FilterMode}
     * @description Filter mode settings of texture.
     * @sdk 9.8.0
     */
    filterMode: FilterMode;
    /**
     * @name Texture#maxAnisotropy
     * @type {number}
     * @description Max anisotropy of texture.
     * @sdk 9.8.0
     */
    get maxAnisotropy(): number;
    set maxAnisotropy(maxAnisotropy: number);
}
