import Amaz = effect.Amaz;
import { CompareOp, PolygonMode, FrontFace, CullFace, ShaderType, BlendFactor, BlendOp } from '../base/const';
import Vec2 from '../math/vec2';
import Vec3 from '../math/vec3';
import Vec4 from '../math/vec4';
import Mat4 from '../math/mat4';
import Texture from './texture';
/**
 * @type {Vec2 | Vec3 | Vec4 | Mat4 | Amaz.Texture | Texture | number}
 * @name AttributeTypes
 * @description Possible type of shader attributes.
 * @sdk 9.8.0
 */
declare type AttributeTypes = Vec2 | Vec3 | Vec4 | Mat4 | Amaz.Texture | Texture | number;
/**
 * @class
 * @category Rendering
 * @name RenderState
 * @classdesc RenderState class holds a mesh shader.
 * @description This class is used to represent material in Amazing JS.
 * @sdk 9.8.0
 */
export declare class RenderState {
    constructor(native?: Amaz.RenderState | undefined);
    /**
     * @name RenderState#native
     * @type {Amaz.RenderState}
     * @description Amaz.RenderState (JS RTTI) type of the RenderState class.
     * @sdk 9.8.0
     */
    native: Amaz.RenderState;
    /**
     * @name RenderState#rasterizationState
     * @type {Amaz.RasterizationState}
     * @description Amaz.RasterizationState (JS RTTI) type. Holds settings to rasterization.
     * @sdk 9.8.0
     */
    rasterizationState: Amaz.RasterizationState;
    /**
     * @name RenderState#depthStencilState
     * @type {Amaz.DepthStencilState}
     * @description Amaz.RasterizationState (JS RTTI) type. Holds settings to depth and stencil.
     * @sdk 9.8.0
     */
    depthStencilState: Amaz.DepthStencilState;
    /**
     * @name RenderState#colorBlendState
     * @type {Amaz.ColorBlendState}
     * @description Amaz.ColorBlendState (JS RTTI) type. Holds array of color blend attachments.
     * @sdk 9.8.0
     */
    colorBlendState: Amaz.ColorBlendState;
    /**
     * @name RenderState#colorBlendAttachmentState
     * @type {Amaz.ColorBlendAttachmentState}
     * @description Amaz.ColorBlendAttachmentState (JS RTTI) type. Holds settings to color blending.
     * @sdk 9.8.0
     */
    colorBlendAttachmentState: Amaz.ColorBlendAttachmentState;
}
/**
 * @class
 * @category Rendering
 * @name Shader
 * @classdesc Shader class that is used by a material (vertex, framgment, compute).
 * @description This class is used to represent a shader.
 * @param {ShaderType} type Type of shader: vertex/ fargment/ compute
 * @sdk 9.8.0
 */
export declare class Shader {
    constructor(type: ShaderType, source?: string);
    /**
     * @name Shader#native
     * @type {Amaz.Shader}
     * @description Amaz.Shader (JS RTTI) class.
     * @sdk 9.8.0
     */
    native: Amaz.Shader;
    /**
     * @name Shader#type
     * @type {ShaderType}
     * @description Type of shader (vertex, fragment, or compute).
     * @sdk 9.8.0
     */
    private _type;
    get type(): ShaderType;
    set type(type: ShaderType);
    /**
     * @name Shader#source
     * @type {string}
     * @description The source code of the shader.
     * @sdk 9.8.0
     */
    private _source;
    get source(): string;
    set source(source: string);
}
/**
 * @interface
 * @name XShaderOptions
 * @description Options avaliable for sahder.
 * @sdk 9.8.0
 */
export interface XShaderOptions {
    cullMode: CullFace;
    frontFace: FrontFace;
    polygonMode: PolygonMode;
    depthTestEnable: boolean;
    depthWriteEnable: boolean;
    stencilTestEnable: boolean;
    depthCompareOp: CompareOp;
    srcColorBlendFactor: BlendFactor;
    dstColorBlendFactor: BlendFactor;
    srcAlphaBlendFactor: BlendFactor;
    dstAlphaBlendFactor: BlendFactor;
    colorBlendOp: BlendOp;
    alphaBlendOp: BlendOp;
    blendEnable: boolean;
}
/**
 * @interface
 * @name XShaderData
 * @description XShader data used to create shader.
 * @sdk 9.8.0
 */
export interface XShaderData {
    native: Amaz.XShader | undefined;
    path: string | undefined;
    vertex: string | undefined;
    fragment: string | undefined;
    attributes: Map<string, AttributeTypes> | undefined;
    language: string | undefined;
    options: XShaderOptions | undefined;
}
/**
 * @class
 * @category Rendering
 * @name XShader
 * @classdesc The xshader class held by the material. Contains vertex and fragment shader.
 * @description Constructor to create XShader instance.
 * @param {Map<string, AttributeTypes>} attributes semantics that are used in the shader.
 * @param {string} vsSource vertex shader source code.
 * @param {string} fsSource fragment shader source code.
 * @param {string} shaderLanguage shader language used for the shaders. (Defaults to gles2).
 * @sdk 9.8.0
 */
export default class XShader {
    /**
     * @function
     * @name XShader#fromNative
     * @description Initialize XShader class with Amaz.XShader class.
     * @param {Amaz.XShader} native Amaz.XShader used to initialize XShader class.
     * @returns {void}
     * @sdk 9.8.0
     */
    private fromNative;
    /**
     * @function
     * @name XShader#fromOptions
     * @description Intialize shader options
     * @param {XShaderOptions} options Shader options used in shader.
     * @returns {void}
     * @sdk 9.8.0
     */
    private fromOptions;
    constructor(xShaderData: XShaderData);
    /**
     * @name XShader#native
     * @type {Amaz.XShader}
     * @description Amaz.XShder class of Shader class.
     * @sdk 9.8.0
     */
    native: Amaz.XShader;
    /**
     * @name XShader#vertexShader
     * @type {Shader}
     * @description Vertex shader used in by the shader class.
     * @sdk 9.8.0
     */
    vertexShader: Shader;
    /**
     * @name XShader#fragmentShader
     * @type {Shader}
     * @description Fragment shader used in by the shader class.
     * @sdk 9.8.0
     */
    fragmentShader: Shader;
    /**
     * @name XShader#attributes
     * @type {Map<string, AttributeTypes>}
     * @description Attributes used in the shader.
     * @sdk 9.8.0
     */
    attributes: Map<string, AttributeTypes>;
    /**
     * @name XShader#renderState
     * @type {RenderState}
     * @description Holds the settings avalibale for the shader.
     * @sdk 9.8.0
     */
    private renderState;
    /**
     * @name XShader#cullMode
     * @type {CullFace}
     * @description Culling method used by the shader.
     * @sdk 9.8.0
     */
    private _cullMode;
    get cullMode(): CullFace;
    set cullMode(cullMode: CullFace);
    /**
     * @name XShader#frontFace
     * @type {FrontFace}
     * @description Holds the settings of how vertices are rendered.
     * @sdk 9.8.0
     */
    private _frontFace;
    get frontFace(): FrontFace;
    set frontFace(frontFace: FrontFace);
    /**
     * @name XShader#polygonMode
     * @type {PolygonMode}
     * @description Holds the settings of how plygons are rendered.
     * @sdk 9.8.0
     */
    private _polygonMode;
    get polygonMode(): PolygonMode;
    set polygonMode(polyMode: PolygonMode);
    /**
     * @name XShader#depthTestEnable
     * @type {boolean}
     * @description Settings for enabling/ disable depth test.
     * @sdk 9.8.0
     */
    private _depthTestEnable;
    get depthTestEnable(): boolean;
    set depthTestEnable(deptTestEnable: boolean);
    /**
     * @name XShader#depthWriteEnable
     * @type {boolean}
     * @description Settings for enabling/ disable depth write.
     * @sdk 9.8.0
     */
    private _depthWriteEnable;
    get depthWriteEnable(): boolean;
    set depthWriteEnable(depthWriteEnable: boolean);
    /**
     * @name XShader#stencilTestEnable
     * @type {boolean}
     * @description Settings for enabling/ disable stencil test.
     * @sdk 9.8.0
     */
    private _stencilTestEnable;
    get stencilTestEnable(): boolean;
    set stencilTestEnable(stencilTestEnable: boolean);
    /**
     * @name XShader#depthCompareOp
     * @type {CompareOp}
     * @description Operation used for depth comparison.
     * @sdk 9.8.0
     */
    private _depthCompareOp;
    get depthCompareOp(): CompareOp;
    set depthCompareOp(depthCompareOp: CompareOp);
    /**
     * @name XShader#srcColorBlendFactor
     * @type {BlendFactor}
     * @description Blend factor for source color.
     * @sdk 9.8.0
     */
    _srcColorBlendFactor: BlendFactor;
    get srcColorBlendFactor(): BlendFactor;
    set srcColorBlendFactor(srcColorBlendFactor: BlendFactor);
    /**
     * @name XShader#dstColorBlendFactor
     * @type {BlendFactor}
     * @description Blend factor for destination color.
     * @sdk 9.8.0
     */
    _dstColorBlendFactor: BlendFactor;
    get dstColorBlendFactor(): BlendFactor;
    set dstColorBlendFactor(dstColorBlendFactor: BlendFactor);
    /**
     * @name XShader#srcAlphaBlendFactor
     * @type {BlendFactor}
     * @description Blend factor for source alpha.
     * @sdk 9.8.0
     */
    _srcAlphaBlendFactor: BlendFactor;
    get srcAlphaBlendFactor(): BlendFactor;
    set srcAlphaBlendFactor(srcAlphaBlendFactor: BlendFactor);
    /**
     * @name XShader#srcAlphaBlendFactor
     * @type {BlendFactor}
     * @description Blend factor for destination alpha.
     * @sdk 9.8.0
     */
    _dstAlphaBlendFactor: BlendFactor;
    get dstAlphaBlendFactor(): BlendFactor;
    set dstAlphaBlendFactor(dstAlphaBlendFactor: BlendFactor);
    /**
     * @name XShader#colorBlendOp
     * @type {BlendOp}
     * @description Operation for color blending.
     * @sdk 9.8.0
     */
    _colorBlendOp: BlendOp;
    get colorBlendOp(): BlendOp;
    set colorBlendOp(colorBlendOp: BlendOp);
    /**
     * @name XShader#alphaBlendOp
     * @type {BlendOp}
     * @description Operation for alpha blending.
     * @sdk 9.8.0
     */
    _alphaBlendOp: BlendOp;
    get alphaBlendOp(): BlendOp;
    set alphaBlendOp(alphaBlendOp: BlendOp);
    /**
     * @name XShader#blendEnable
     * @type {boolean}
     * @description Enable/ disable aplha and color blending.
     * @sdk 9.8.0
     */
    private _blendEnable;
    get blendEnable(): boolean;
    set blendEnable(blendEnable: boolean);
}
export {};
