import Component from './component';
import SceneObject from '../scene/scene-object';
import { AnimationPlayMode } from '../base/const';
import Animation from '../base/animation';
interface AnimationOptions {
    animations: Array<Animation>;
}
interface AnimationPlayOptions {
    playMode?: AnimationPlayMode;
    speed?: number;
    fadeTime?: number;
    startTime?: number;
}
/**
 * @class
 * @category Component
 * @name AnimationComponent
 * @augments Component
 * @classdesc AnimationComponent class for playing animations.
 * @description Constructor to create an AnimationComponent instance.
 * To add an AnimationComponent to an {@link SceneObject},
 * use {@link SceneObject#addComponent}.
 * @param {SceneObject} sceneObject - The sceneObject.
 * @param {object} options - Options to create AnimationComponent.
 * @example
 * // add AnimationComponent to sceneObject
 * sceneObject.addComponent('Animation', options);
 * @hideconstructor
 * @sdk 9.8.0
 */
export default class AnimationComponent extends Component {
    static register(): void;
    static nativeClasses: Array<string>;
    constructor(sceneObject?: SceneObject, options?: AnimationOptions);
    static fromNative(sceneObject: SceneObject, native: any): AnimationComponent;
    protected getProps(): Array<string>;
    /**
     * @function
     * @name AnimationComponent#play
     * @description Play animation.
     * @param {string} name - Name of the animation.
     * @param {AnimationPlayOptions} state - Options to play animation.
     * @param {amg.AnimationPlayMode} state.playMode - Play mode.
     * @param {number} state.speed - Play speed.
     * @param {number} state.fadeTime - Fade time.
     * @param {number} state.startTime - Start time.
     * @sdk 9.8.0
     */
    play(name: string, state: AnimationPlayOptions | undefined): void;
    /**
     * @function
     * @name AnimationComponent#stop
     * @description Stop animation.
     * @sdk 9.8.0
     */
    stop(): void;
    /**
     * @function
     * @name AnimationComponent#pause
     * @description Pause animation.
     * @sdk 9.8.0
     */
    pause(): void;
    /**
     * @function
     * @name AnimationComponent#resume
     * @description Resume animation.
     * @sdk 9.8.0
     */
    resume(): void;
    /**
     * @name AnimationComponent#animations
     * @type {Array<Animation>}
     * @description The list of animations.
     * @sdk 9.8.0
     */
    get animations(): Array<Animation>;
    set animations(value: Array<Animation>);
}
export {};
