import Amaz = effect.Amaz;
import SceneObject from '../scene/scene-object';
import Component from './component';
import Color from '../math/color';
import Rect from '../math/rect';
import Vec3 from '../math/vec3';
import { CameraType } from '../base/const';
import RenderTexture = Amaz.RenderTexture;
interface CameraOptions {
    clearColor?: Color;
    clearColorBuffer?: boolean;
    clearDepthBuffer?: boolean;
    clearStencilBuffer?: boolean;
    orthoHeight?: number;
    near?: number;
    far?: number;
    fov?: number;
    type: CameraType;
    viewport?: Rect;
    layers?: number[];
    renderOrder?: number;
}
/**
 * @class
 * @category Component
 * @name CameraComponent
 * @augments Component
 * @classdesc CameraComponent class for rendering camera.
 * @description Constructor to create an CameraComponent instance.
 * To add an CameraComponent to an {@link SceneObject},
 * use {@link SceneObject#addComponent}.
 * @param {SceneObject} sceneObject - The sceneObject.
 * @param {object} options - Options to create CameraComponent.
 * @example
 * // add CameraComponent to sceneObject
 * sceneObject.addComponent('Camera', options);
 * @hideconstructor
 * @sdk 9.8.0
 */
export default class CameraComponent extends Component {
    static register(): void;
    static nativeClasses: Array<string>;
    constructor(sceneObject?: SceneObject, options?: CameraOptions);
    static fromNative(sceneObject: SceneObject, native: any): CameraComponent;
    /**
     * @name CameraComponent#renderTexture
     * @type {RenderTexture}
     * @description Target texture for rendering.
     * @sdk 9.8.0
     */
    get renderTexture(): RenderTexture;
    set renderTexture(value: RenderTexture);
    /**
     * @name CameraComponent#clearColor
     * @type {Color}
     * @description Color used to clear color buffer.
     * @sdk 9.8.0
     */
    get clearColor(): Color;
    set clearColor(value: Color);
    /**
     * @name CameraComponent#clearColorBuffer
     * @type {boolean}
     * @description Flag to clear color buffer.
     * @sdk 9.8.0
     */
    get clearColorBuffer(): boolean;
    set clearColorBuffer(value: boolean);
    /**
     * @name CameraComponent#clearDepthBuffer
     * @type {boolean}
     * @description Flag to clear depth buffer.
     * @sdk 9.8.0
     */
    get clearDepthBuffer(): boolean;
    set clearDepthBuffer(value: boolean);
    /**
     * @name CameraComponent#clearStencilBuffer
     * @type {boolean}
     * @description Flag to clear stencil buffer.
     * @sdk 9.8.0
     */
    get clearStencilBuffer(): boolean;
    set clearStencilBuffer(value: boolean);
    /**
     * @name CameraComponent#orthoHeight
     * @type {number}
     * @description Camera's half-size when in orthographic mode.
     * @sdk 9.8.0
     */
    get orthoHeight(): number;
    set orthoHeight(value: number);
    /**
     * @name CameraComponent#near
     * @type {number}
     * @description Camera's near distance.
     * @sdk 9.8.0
     */
    get near(): number;
    set near(value: number);
    /**
     * @name CameraComponent#far
     * @type {number}
     * @description Camera's far distance.
     * @sdk 9.8.0
     */
    get far(): number;
    set far(value: number);
    /**
     * @name CameraComponent#fov
     * @type {number}
     * @description Camera's field of view angle (in degrees).
     * @sdk 9.8.0
     */
    get fov(): number;
    set fov(value: number);
    /**
     * @name CameraComponent#type
     * @type {amg.CameraType}
     * @description Camera's type.
     * @sdk 9.8.0
     */
    get type(): CameraType;
    set type(value: CameraType);
    /**
     * @name CameraComponent#viewport
     * @type {Rect}
     * @description Camera's viewport.
     * @sdk 9.8.0
     */
    get viewport(): Rect;
    set viewport(value: Rect);
    /**
     * @name CameraComponent#layers
     * @type {number[]}
     * @description Camera's rendering layers.
     * @sdk 9.8.0
     */
    get layers(): number[];
    set layers(value: number[]);
    /**
     * @name CameraComponent#renderOrder
     * @type {number}
     * @description Camera's rendering order.
     * @sdk 9.8.0
     */
    get renderOrder(): number;
    set renderOrder(value: number);
    /**
     * @function
     * @name CameraComponent#screenToWorld
     * @description Convert 2D point to 3D point.
     * @param {Vec3} point - 2D point with desired z.
     * @returns {Vec3} 3D point.
     * @sdk 9.8.0
     */
    screenToWorld(point: Vec3): Vec3;
    /**
     * @function
     * @name CameraComponent#worldToScreen
     * @description Convert 3D point to 2D point.
     * @param {Vec3} point - 3D point.
     * @returns {Vec3} 2D point with z.
     * @sdk 9.8.0
     */
    worldToScreen(point: Vec3): Vec3;
}
export {};
