import SceneObject from '../scene/scene-object';
import Component from './component';
import Color from '../math/color';
import { LightType } from '../base/const';
import Vec2 from '../math/vec2';
interface LightOptions {
    type: LightType;
    color?: Color;
    intensity?: number;
    castShadow?: boolean;
    enableSoftShadow?: boolean;
    shadowSoftness?: number;
    shadowBias?: number;
    camera?: SceneObject;
    shadowResolution?: Vec2;
    attenuationRange?: number;
}
/**
 * @class
 * @category Component
 * @name LightComponent
 * @augments Component
 * @classdesc LightComponent class for lighting.
 * @description Constructor to create an LightComponent instance.
 * To add an LightComponent to an {@link SceneObject},
 * use {@link SceneObject#addComponent}.
 * @param {SceneObject} sceneObject - The sceneObject.
 * @param {object} options - Options to create LightComponent.
 * @param {amg.LightType} options.type - Type of light.
 * @example
 * // add LightComponent to sceneObject
 * sceneObject.addComponent('Light', {type: amg.LightType.Directional});
 * @hideconstructor
 * @sdk 9.8.0
 */
export default class LightComponent extends Component {
    static register(): void;
    static nativeClasses: Array<string>;
    type: LightType;
    constructor(sceneObject?: SceneObject, options?: LightOptions);
    static fromNative(sceneObject: SceneObject, native: any): LightComponent;
    /**
     * @name LightComponent#color
     * @type {Color}
     * @description Light's color.
     * @sdk 9.8.0
     */
    get color(): Color;
    set color(value: Color);
    /**
     * @name LightComponent#intensity
     * @type {number}
     * @description Light's intensity.
     * @sdk 9.8.0
     */
    get intensity(): number;
    set intensity(value: number);
    /**
     * @name LightComponent#castShadow
     * @type {boolean}
     * @description Light's cast shadow flag.
     * @sdk 9.8.0
     */
    get castShadow(): boolean;
    set castShadow(value: boolean);
    /**
     * @name LightComponent#enableSoftShadow
     * @type {boolean}
     * @description Light's enable soft shadow flag.
     * @sdk 9.8.0
     */
    get enableSoftShadow(): boolean;
    set enableSoftShadow(value: boolean);
    /**
     * @name LightComponent#shadowSoftness
     * @type {number}
     * @description Light's shadow softness.
     * @sdk 9.8.0
     */
    get shadowSoftness(): number;
    set shadowSoftness(value: number);
    /**
     * @name LightComponent#shadowBias
     * @type {number}
     * @description Light's shadow sias.
     * @sdk 9.8.0
     */
    get shadowBias(): number;
    set shadowBias(value: number);
    /**
     * @name LightComponent#shadowResolution
     * @type {Vec2}
     * @description Light's shadow resolution.
     * @sdk 9.8.0
     */
    get shadowResolution(): Vec2;
    set shadowResolution(value: Vec2);
    /**
     * @name LightComponent#attenuationRange
     * @type {number}
     * @description Light's attenuation range.
     * @sdk 9.8.0
     */
    get attenuationRange(): number;
    set attenuationRange(value: number);
    /**
     * @name LightComponent#camera
     * @type {SceneObject}
     * @description Light's camera for shadow.
     * @sdk 9.8.0
     */
    get camera(): SceneObject | undefined;
    set camera(value: SceneObject | undefined);
}
export {};
