import Amaz = effect.Amaz;
import Component from './component';
import SceneObject from '../scene/scene-object';
import Material from '../base/material';
import { ParticleSystemAffector, ParticleSystemColorAffectorOperation, ParticleSystemRenderDisplayMode, ParticleSystemRenderOrientation, ParticleSystemRenderSortingMode, ParticleSystemRenderType } from '../base/const';
import Mesh = Amaz.Mesh;
import Vec3 from '../math/vec3';
interface ParticleRandomValue {
    min: number;
    max: number;
}
interface TimeColorValue {
    time: number;
    color: Amaz.Color;
}
interface ParticleSystemOptions {
    autoPlay?: boolean;
    flipDirection?: boolean;
    totalParticles?: number;
    material?: Material;
    emitterRadius?: ParticleRandomValue;
    emissionRate?: ParticleRandomValue;
    lifetime?: ParticleRandomValue;
    scale?: ParticleRandomValue;
    angle?: ParticleRandomValue;
    speed?: ParticleRandomValue;
    rotationX?: ParticleRandomValue;
    rotationY?: ParticleRandomValue;
    rotationZ?: ParticleRandomValue;
    rotationXSpeed?: ParticleRandomValue;
    rotationYSpeed?: ParticleRandomValue;
    rotationZSpeed?: ParticleRandomValue;
    colors?: Array<Amaz.Color>;
    orientation?: ParticleSystemRenderOrientation;
    sortingMode?: ParticleSystemRenderSortingMode;
    renderType?: ParticleSystemRenderType;
    mesh?: Mesh;
    displayMode?: ParticleSystemRenderDisplayMode;
    orientationStart?: Vec3;
    orientationEnd?: Vec3;
    affectorType?: ParticleSystemAffector;
    colorAffectorOperation?: ParticleSystemColorAffectorOperation;
    colorAffectorColors?: Array<TimeColorValue>;
}
/**
 * @class
 * @category Component
 * @name ParticleSystemComponent
 * @augments Component
 * @classdesc ParticleSystemComponent class for particle system simulation.
 * @description Constructor to create an ParticleSystemComponent instance.
 * To add an ParticleSystemComponent to an {@link SceneObject},
 * use {@link SceneObject#addComponent}.
 * @param {SceneObject} sceneObject - The sceneObject.
 * @param {object} options - Options to create ParticleSystemComponent.
 * @param {amg.ParticleSystemAffector} options.affectorType - Options to add affector.
 * @example
 * // add ParticleSystemComponent to sceneObject
 * sceneObject.addComponent('ParticleSystem', options);
 * @hideconstructor
 * @sdk 9.8.0
 */
export default class ParticleSystemComponent extends Component {
    static register(): void;
    static nativeClasses: Array<string>;
    private _material;
    constructor(sceneObject?: SceneObject, options?: ParticleSystemOptions);
    static fromNative(sceneObject: SceneObject, native: any): ParticleSystemComponent;
    private getEmitter;
    private getAffector;
    protected getProps(): Array<string>;
    /**
     * @function
     * @name ParticleSystemComponent#isPlaying
     * @description Check if particle system's playing.
     * @sdk 9.8.0
     */
    isPlaying(): boolean;
    /**
     * @function
     * @name ParticleSystemComponent#start
     * @description Start particle system.
     * @sdk 9.8.0
     */
    start(): boolean;
    /**
     * @function
     * @name ParticleSystemComponent#stop
     * @description Stop particle system.
     * @sdk 9.8.0
     */
    stop(): boolean;
    /**
     * @function
     * @name ParticleSystemComponent#resume
     * @description Resume particle system.
     * @sdk 9.8.0
     */
    resume(): boolean;
    /**
     * @function
     * @name ParticleSystemComponent#pause
     * @description Pause particle system.
     * @sdk 9.8.0
     */
    pause(): boolean;
    /**
     * @name ParticleSystemComponent#orientation
     * @type {amg.ParticleSystemRenderOrientation}
     * @description Particle system's orientation type.
     * @sdk 9.8.0
     */
    get orientation(): ParticleSystemRenderOrientation;
    set orientation(value: ParticleSystemRenderOrientation);
    /**
     * @name ParticleSystemComponent#sortingMode
     * @type {amg.ParticleSystemRenderSortingMode}
     * @description Particle system's sorting mode.
     * @sdk 9.8.0
     */
    get sortingMode(): ParticleSystemRenderSortingMode;
    set sortingMode(value: ParticleSystemRenderSortingMode);
    /**
     * @name ParticleSystemComponent#displayMode
     * @type {amg.ParticleSystemRenderDisplayMode}
     * @description Particle system's display mode.
     * @sdk 9.8.0
     */
    get displayMode(): ParticleSystemRenderDisplayMode;
    set displayMode(value: ParticleSystemRenderDisplayMode);
    /**
     * @name ParticleSystemComponent#mesh
     * @type {Mesh}
     * @description Particle system's mesh.
     * @sdk 9.8.0
     */
    get mesh(): Mesh;
    set mesh(value: Mesh);
    /**
     * @name ParticleSystemComponent#autoPlay
     * @type {boolean}
     * @description Particle system's auto play flag.
     * @sdk 9.8.0
     */
    get autoPlay(): boolean;
    set autoPlay(value: boolean);
    /**
     * @name ParticleSystemComponent#flipDirection
     * @type {boolean}
     * @description Particle system's flip direction flag.
     * @sdk 9.8.0
     */
    get flipDirection(): boolean;
    set flipDirection(value: boolean);
    /**
     * @name ParticleSystemComponent#totalParticles
     * @type {number}
     * @description Particle system's total particles.
     * @sdk 9.8.0
     */
    get totalParticles(): number;
    set totalParticles(value: number);
    /**
     * @name ParticleSystemComponent#material
     * @type {Material | undefined}
     * @description Particle system's material.
     * @sdk 9.8.0
     */
    get material(): Material | undefined;
    set material(value: Material | undefined);
    /**
     * @name ParticleSystemComponent#emitterRadius
     * @type {object}
     * @description Particle system's emitter radius.
     * <table>
     *  <tr><td>min</td><td>number</td></tr>
     *  <tr><td>max</td><td>number</td></tr>
     * </table>
     * @sdk 9.8.0
     */
    get emitterRadius(): ParticleRandomValue;
    set emitterRadius(param: ParticleRandomValue);
    /**
     * @name ParticleSystemComponent#emissionRate
     * @type {object}
     * @description Particle emitter's emission rate.
     * <table>
     *  <tr><td>min</td><td>number</td></tr>
     *  <tr><td>max</td><td>number</td></tr>
     * </table>
     * @sdk 9.8.0
     */
    get emissionRate(): ParticleRandomValue;
    set emissionRate(param: ParticleRandomValue);
    /**
     * @name ParticleSystemComponent#lifetime
     * @type {object}
     * @description Particle's life time.
     * <table>
     *  <tr><td>min</td><td>number</td></tr>
     *  <tr><td>max</td><td>number</td></tr>
     * </table>
     * @sdk 9.8.0
     */
    get lifetime(): ParticleRandomValue;
    set lifetime(param: ParticleRandomValue);
    /**
     * @name ParticleSystemComponent#scale
     * @type {object}
     * @description Particle's scale.
     * <table>
     *  <tr><td>min</td><td>number</td></tr>
     *  <tr><td>max</td><td>number</td></tr>
     * </table>
     * @sdk 9.8.0
     */
    get scale(): ParticleRandomValue;
    set scale(param: ParticleRandomValue);
    /**
     * @name ParticleSystemComponent#angle
     * @type {object}
     * @description Particle's angle.
     * <table>
     *  <tr><td>min</td><td>number</td></tr>
     *  <tr><td>max</td><td>number</td></tr>
     * </table>
     * @sdk 9.8.0
     */
    get angle(): ParticleRandomValue;
    set angle(param: ParticleRandomValue);
    /**
     * @name ParticleSystemComponent#speed
     * @type {object}
     * @description Particle's speed.
     * <table>
     *  <tr><td>min</td><td>number</td></tr>
     *  <tr><td>max</td><td>number</td></tr>
     * </table>
     * @sdk 9.8.0
     */
    get speed(): ParticleRandomValue;
    set speed(param: ParticleRandomValue);
    /**
     * @name ParticleSystemComponent#rotationX
     * @type {object}
     * @description Particle's rotation around X axis.
     * <table>
     *  <tr><td>min</td><td>number</td></tr>
     *  <tr><td>max</td><td>number</td></tr>
     * </table>
     * @sdk 9.8.0
     */
    get rotationX(): ParticleRandomValue;
    set rotationX(param: ParticleRandomValue);
    /**
     * @name ParticleSystemComponent#rotationY
     * @type {object}
     * @description Particle's rotation around Y axis.
     * <table>
     *  <tr><td>min</td><td>number</td></tr>
     *  <tr><td>max</td><td>number</td></tr>
     * </table>
     * @sdk 9.8.0
     */
    get rotationY(): ParticleRandomValue;
    set rotationY(param: ParticleRandomValue);
    /**
     * @name ParticleSystemComponent#rotationZ
     * @type {object}
     * @description Particle's rotation around Z axis.
     * <table>
     *  <tr><td>min</td><td>number</td></tr>
     *  <tr><td>max</td><td>number</td></tr>
     * </table>
     * @sdk 9.8.0
     */
    get rotationZ(): ParticleRandomValue;
    set rotationZ(param: ParticleRandomValue);
    /**
     * @name ParticleSystemComponent#rotationXSpeed
     * @type {object}
     * @description Particle's rotation speed around X axis.
     * <table>
     *  <tr><td>min</td><td>number</td></tr>
     *  <tr><td>max</td><td>number</td></tr>
     * </table>
     * @sdk 9.8.0
     */
    get rotationXSpeed(): ParticleRandomValue;
    set rotationXSpeed(param: ParticleRandomValue);
    /**
     * @name ParticleSystemComponent#rotationYSpeed
     * @type {object}
     * @description Particle's rotation speed around Y axis.
     * <table>
     *  <tr><td>min</td><td>number</td></tr>
     *  <tr><td>max</td><td>number</td></tr>
     * </table>
     * @sdk 9.8.0
     */
    get rotationYSpeed(): ParticleRandomValue;
    set rotationYSpeed(param: ParticleRandomValue);
    /**
     * @name ParticleSystemComponent#rotationZSpeed
     * @type {object}
     * @description Particle's rotation speed around Z axis.
     * <table>
     *  <tr><td>min</td><td>number</td></tr>
     *  <tr><td>max</td><td>number</td></tr>
     * </table>
     * @sdk 9.8.0
     */
    get rotationZSpeed(): ParticleRandomValue;
    set rotationZSpeed(param: ParticleRandomValue);
    /**
     * @name ParticleSystemComponent#colors
     * @type {Array<Amaz.Color>}
     * @description Particle's random color list.
     * @sdk 9.8.0
     */
    set colors(inColors: Array<Amaz.Color>);
    /**
     * @name ParticleSystemComponent#orientationStart
     * @type {Vec3}
     * @description Particle's orientation start angles.
     * @sdk 9.8.0
     */
    get orientationStart(): Vec3;
    set orientationStart(value: Vec3);
    /**
     * @name ParticleSystemComponent#orientationEnd
     * @type {Vec3}
     * @description Particle's orientation end angles.
     * @sdk 9.8.0
     */
    get orientationEnd(): Vec3;
    set orientationEnd(value: Vec3);
    /**
     * @name ParticleSystemComponent#colorAffectorOperation
     * @type {amg.ParticleSystemColorAffectorOperation}
     * @description Particle's color affector's operation.
     * @sdk 9.8.0
     */
    get colorAffectorOperation(): ParticleSystemColorAffectorOperation;
    set colorAffectorOperation(param: ParticleSystemColorAffectorOperation);
    /**
     * @name ParticleSystemComponent#colorAffectorColors
     * @type {Array<object>}
     * @description Particle's color affector's operation.
     * <table>
     *  <tr><td>time</td><td>number</td></tr>
     *  <tr><td>color</td><td>Color</td></tr>
     * </table>
     * @sdk 9.8.0
     */
    get colorAffectorColors(): Array<TimeColorValue>;
    set colorAffectorColors(timeColors: Array<TimeColorValue>);
}
export {};
