import SceneObject from '../scene/scene-object';
import { Physics3DOptions, Physics3DComponent } from './physics3d-component';
import Vec3 from '../math/vec3';
interface RigidBody3DOptions extends Physics3DOptions {
    angularDamping?: number;
    angularFactor?: Vec3;
    angularVelocity?: Vec3;
    linearDamping?: number;
    linearFactor?: Vec3;
    linearVelocity?: Vec3;
    gravityAcceleration?: Vec3;
}
/**
 * @class
 * @category Component
 * @name RigidBody3DComponent
 * @augments Physics3DComponent
 * @classdesc RigidBody3DComponent class 3d rigid body simulation.
 * @description Constructor to create an RigidBody3DComponent instance.
 * To add an RigidBody3DComponent to an {@link SceneObject},
 * use {@link SceneObject#addComponent}.
 * @param {SceneObject} sceneObject - The sceneObject.
 * @param {object} options - Options to create RigidBody3DComponent.
 * @example
 * // add RigidBody3DComponent to sceneObject
 * sceneObject.addComponent('RigidBody', options);
 * @hideconstructor
 * @sdk 9.8.0
 */
/**
 * @event
 * @name RigidBody3DComponent#triggerenter
 * @description Fired after rigid body entered trigger.
 * @param {SceneObject} thisSceneObject - The sceneObject triggers this event.
 * @param {SceneObject} otherSceneObject - The other sceneObject hit by this sceneObject.
 * @param {Array<ContactPoint3D>} contacts - A list of 3d contact points.
 * @example
 * sceneObject.rigidBody.on('triggerenter', function () {
 *     console.log('SceneObject entered');
 * });
 * @sdk 9.8.0
 */
/**
 * @event
 * @name RigidBody3DComponent#collisionenter
 * @description Fired after rigid body entered collision with other rigid body.
 * @param {SceneObject} thisSceneObject - The sceneObject triggers this event.
 * @param {SceneObject} otherSceneObject - The other sceneObject hit by this sceneObject.
 * @param {Array<ContactPoint3D>} contacts - A list of 3d contact points.
 * @example
 * sceneObject.rigidBody.on('collisionenter', function () {
 *     console.log('SceneObject entered');
 * });
 * @sdk 9.8.0
 */
/**
 * @event
 * @name RigidBody3DComponent#triggerexit
 * @description Fired after rigid body exited trigger.
 * @param {SceneObject} thisSceneObject - The sceneObject triggers this event.
 * @param {SceneObject} otherSceneObject - The other sceneObject hit by this sceneObject.
 * @param {Array<ContactPoint3D>} contacts - A list of 3d contact points.
 * @example
 * sceneObject.rigidBody.on('triggerexit', function () {
 *     console.log('SceneObject exited');
 * });
 * @sdk 9.8.0
 */
/**
 * @event
 * @name RigidBody3DComponent#collisionexit
 * @description Fired after rigid body exited collision with other rigid body.
 * @param {SceneObject} thisSceneObject - The sceneObject triggers this event.
 * @param {SceneObject} otherSceneObject - The other sceneObject hit by this sceneObject.
 * @param {Array<ContactPoint3D>} contacts - A list of 3d contact points.
 * @example
 * sceneObject.rigidBody.on('collisionexit', function () {
 *     console.log('SceneObject exited');
 * });
 * @sdk 9.8.0
 */
/**
 * @event
 * @name RigidBody3DComponent#triggerstay
 * @description Fired while rigid body is staying trigger.
 * @param {SceneObject} thisSceneObject - The sceneObject triggers this event.
 * @param {SceneObject} otherSceneObject - The other sceneObject hit by this sceneObject.
 * @param {Array<ContactPoint3D>} contacts - A list of 3d contact points.
 * @example
 * sceneObject.rigidBody.on('triggerstay', function () {
 *     console.log('SceneObject exited');
 * });
 * @sdk 9.8.0
 */
/**
 * @event
 * @name RigidBody3DComponent#collisionstay
 * @description Fired while rigid body is staying collision with other rigid body.
 * @param {SceneObject} thisSceneObject - The sceneObject triggers this event.
 * @param {SceneObject} otherSceneObject - The other sceneObject hit by this sceneObject.
 * @param {Array<ContactPoint3D>} contacts - A list of 3d contact points.
 * @example
 * sceneObject.rigidBody.on('collisionstay', function () {
 *     console.log('SceneObject stays');
 * });
 * @sdk 9.8.0
 */
export default class RigidBody3DComponent extends Physics3DComponent {
    constructor(sceneObject?: SceneObject, options?: RigidBody3DOptions);
    static fromNative(sceneObject: SceneObject, native: any): RigidBody3DComponent;
    destroy(): void;
    protected getProps(): Array<string>;
    protected initialize(options: Physics3DOptions, props: Array<string>): void;
    private reset;
    /**
     * @function
     * @name RigidBody3DComponent#teleport
     * @description Move rigid body to new position and rotation.
     * @param {Vec3} position - Local position to move.
     * @param {Vec3} eulerAngles - Local euler angles to move.
     * @sdk 9.8.0
     */
    teleport(position: Vec3, eulerAngles?: Vec3): void;
    /**
     * @function
     * @name RigidBody3DComponent#applyForce
     * @description Apply force to rigid body at position.
     * @param {Vec3} force - Local force to apply.
     * @param {Vec3} position - Local position of the force.
     * @sdk 9.8.0
     */
    applyForce(force: Vec3, position?: Vec3): void;
    /**
     * @function
     * @name RigidBody3DComponent#applyTorque
     * @description Apply torque to rigid body.
     * @param {Vec3} torque - Local torque to apply.
     * @sdk 9.8.0
     */
    applyTorque(torque: Vec3): void;
    /**
     * @function
     * @name RigidBody3DComponent#applyImpusle
     * @description Apply impulse to rigid body.
     * @param {Vec3} impulse - Local impulse to apply.
     * @param {Vec3} position - Local position to apply.
     * @sdk 9.8.0
     */
    applyImpusle(impulse: Vec3, position?: Vec3): void;
    /**
     * @function
     * @name RigidBody3DComponent#applyTorqueImpulse
     * @description Apply torque impulse to rigid body.
     * @param {Vec3} torqueImpulse - Local torque impulse to apply.
     * @sdk 9.8.0
     */
    applyTorqueImpulse(torqueImpulse: Vec3): void;
    /**
     * @name RigidBody3DComponent#angularDamping
     * @type {number}
     * @description Rigid body's angular damping.
     * @sdk 9.8.0
     */
    get angularDamping(): number;
    set angularDamping(value: number);
    /**
     * @name RigidBody3DComponent#angularFactor
     * @type {Vec3}
     * @description Rigid body's angular factor.
     * @sdk 9.8.0
     */
    get angularFactor(): Vec3;
    set angularFactor(value: Vec3);
    /**
     * @name RigidBody3DComponent#angularVelocity
     * @type {Vec3}
     * @description Rigid body's angular velocity.
     * @sdk 9.8.0
     */
    get angularVelocity(): Vec3;
    set angularVelocity(value: Vec3);
    /**
     * @name RigidBody3DComponent#linearDamping
     * @type {number}
     * @description Rigid body's linear damping.
     * @sdk 9.8.0
     */
    get linearDamping(): number;
    set linearDamping(value: number);
    /**
     * @name RigidBody3DComponent#linearFactor
     * @type {Vec3}
     * @description Rigid body's linear factor.
     * @sdk 9.8.0
     */
    get linearFactor(): Vec3;
    set linearFactor(value: Vec3);
    /**
     * @name RigidBody3DComponent#linearVelocity
     * @type {Vec3}
     * @description Rigid body's linear velocity.
     * @sdk 9.8.0
     */
    get linearVelocity(): Vec3;
    set linearVelocity(value: Vec3);
    /**
     * @name RigidBody3DComponent#gravity
     * @type {Vec3}
     * @description Rigid body's gravity acceleration.
     * @sdk 9.8.0
     */
    get gravityAcceleration(): Vec3;
    set gravityAcceleration(value: Vec3);
    private registerCallbacks;
    private removeCallbacks;
    private onCollisionEnter;
    private onCollisionStay;
    private onCollisionExit;
}
export {};
