import Matrix from './matrix';
import Amaz = effect.Amaz;
import Vec3 from './vec3';
/**
 * @class
 * @category Math
 * @name Mat3
 * @classdesc Class for math 3x3 column-major matrix.
 * @description Constructor to create an Mat3 instance column by column - initializes as an identity matrix by default.
 * @param {number} m0 - 1st column's 1st element.
 * @param {number} m1 - 1st column's 2nd element.
 * @param {number} m2 - 1st column's 3rd element.
 * @param {number} m3 - 2nd column's 1st element.
 * @param {number} m4 - 2nd column's 2nd element.
 * @param {number} m5 - 2nd column's 3rd element.
 * @param {number} m6 - 3rd column's 1st element.
 * @param {number} m7 - 3rd column's 2nd element.
 * @param {number} m8 - 3rd column's 3rd element.
 * @sdk 11.7.0
 */
export default class Mat3 extends Matrix {
    constructor();
    constructor(mat: Amaz.Matrix3x3f);
    constructor(m0: number, m1: number, m2: number, m3: number, m4: number, m5: number, m6: number, m7: number, m8: number);
    static fromNative(nativeMat: Amaz.Matrix3x3f): Mat3;
    /**
     * @name Mat3#native
     * @type {Amaz.Matrix3x3f}
     * @description Returns the native data structure of Mat3x3.
     * @sdk 11.7.0
     */
    get native(): Amaz.Matrix3x3f;
    /**
     * @function
     * @name Mat3#set
     * @description Set new elements to this matrix.
     * @param {number} row - Row index.
     * @param {number} col - Column index.
     * @param {number} value - Value to be set for the index.
     * @returns {Mat3} - Self for chaining.
     * @sdk 11.7.0
     */
    set(row: number, col: number, value: number): Mat3;
    /**
     * @function
     * @name Mat3#get
     * @description Get value from row and column index.
     * @param {number} row - Row of element.
     * @param {number} col - Column of element.
     * @returns {number} - Value of element.
     * @sdk 11.7.0
     */
    get(row: number, col: number): number;
    /**
     * @function
     * @name Mat3#getColumn
     * @description Get column vector from column index.
     * @param {number} col - Column index.
     * @param {Vec3} out - Optional ouput vector to store result, otherwise a new vector will be created.
     * @returns {Vec3} - Return output for chaining.
     * @sdk 11.7.0
     */
    getColumn(col: number, out?: Vec3): Vec3;
    /**
     * @function
     * @name Mat3#copy
     * @description Copy the elements from target to this object.
     * @param {Mat3} target - Target.
     * @returns {Mat3} - Self for chaining.
     * @sdk 11.7.0
     */
    copy(target: Mat3): Mat3;
    /**
     * @function
     * @name Mat3#clone
     * @description Returns an identical copy of this object.
     * @returns {Mat3} The cloned instance.
     * @sdk 11.7.0
     */
    clone(): Mat3;
    /**
     * @function
     * @name Mat3#eq
     * @description Checks strict equality of this matrix and other matrix.
     * @param {Mat3} other - Other matrix.
     * @returns {boolean} - Returns true if the matrices are equal and false otherwise.
     * @sdk 11.7.0
     */
    eq(other: Mat3): boolean;
    /**
     * @function
     * @name Mat3#eq
     * @description Checks strict equality of this vector and other vector.
     * @param {Mat3} m0 - first matrix.
     * @param {Mat3} m1 - second matrix.
     * @returns {boolean} - Returns true if the vectors are equal and false otherwise.
     * @static
     * @sdk 11.7.0
     */
    static eq(m0: Mat3, m1: Mat3): boolean;
    /**
     * @function
     * @name Mat3#identity
     * @description Reset to identity matrix.
     * @returns {Mat3} - Self for chaining.
     * @sdk 11.7.0
     */
    identity(): Mat3;
    /**
     * @function
     * @name Mat3#zero
     * @description Reset to zero matrix.
     * @returns {Mat3} - Self for chaining.
     * @sdk 11.7.0
     */
    zero(): Mat3;
    /**
     * @function
     * @name Mat3#isIdentity
     * @description Check if this is an identity matrix.
     * @param {number} epsilon - Epsilon number.
     * @returns {boolean} - True if it is an identity matrix.
     * @sdk 11.7.0
     */
    isIdentity(epsilon?: number): boolean;
    /**
     * @function
     * @name Mat3#isZero
     * @description Check if this is a zero matrix.
     * @param {number} epsilon - Epsilon number.
     * @returns {boolean} - True if it is an zero matrix.
     * @sdk 11.7.0
     */
    isZero(epsilon?: number): boolean;
    /**
     * @function
     * @name Mat3#inv
     * @description Inverse the matrix.
     * @returns {Mat3} Self for chaining.
     * @sdk 11.7.0
     */
    inv(): Mat3;
    /**
     * @function
     * @name Mat3#mul
     * @description Use this Matrix to multiply other matrix.
     * @param {Mat3} m Other matrix.
     * @returns {Mat3} Return self for chaining.
     * @sdk 11.7.0
     */
    mul(m: Mat3): Mat3;
    private transformVec3;
    /**
     * @function
     * @name Mat3#transformVec3
     * @description Use a Matrix to rotate vector.
     * @param {Mat3} m Matrix to rotate vector.
     * @param {Vec3} inV vector to rotate.
     * @returns {Vec3} Output for chaining.
     * @static
     * @sdk 11.7.0
     */
    static transformVec3(m: Mat3, inV: Vec3): Vec3;
    /**
     * @function
     * @name Mat3#scale
     * @description Scale this matrix along X-axis, Y-axis and Z-axis by factor vector.
     * @param {Vec3} factor Factor vector.
     * @returns {Mat3} Self for chaining.
     * @sdk 11.7.0
     */
    scale(factor: Vec3): Mat3;
    /**
     * @function
     * @name Mat3#fromScale
     * @description Convert to scale matrix from scale vector.
     * @param {Vec3} scale Scale vector.
     * @returns {Mat3} Self for chaining.
     * @sdk 11.7.0
     */
    fromScale(scale: Vec3): Mat3;
    /**
     * @function
     * @name Mat3#determinant
     * @description Computes and returns the determinant of this matrix.
     * @returns {number} Determinant of the matrix.
     * @sdk 11.7.0
     */
    determinant(): number;
    /**
     * @function
     * @name Mat3#transpose
     * @description Transpose the matrix.
     * @returns {Mat3} Self for chaining.
     * @sdk 11.7.0
     */
    transpose(): Mat3;
    /**
     * @function
     * @name Mat3#fromEulerAngles
     * @description Convert euler angles to matrix.
     * @param {number} x - Angle around X (in degrees).
     * @param {number} y - Angle around Y (in degrees).
     * @param {number} z - Angle around Z (in degrees).
     * @param {Mat3} out - Output result matrix. If empty, return the new matrix.
     * @returns {Mat3} - return output matrix.
     * @static
     * @sdk 11.7.0
     */
    static fromEulerAngles(x: number, y: number, z: number, out: Mat3): Mat3;
    private fromAxisAngle;
    /**
     * @function
     * @name Mat3#fromAxisAngle
     * @description Convert axis and angle to matrix.
     * @param {Vec3} axis - Rotation axis.
     * @param {number} angle - Roation angle around axis (in degrees).
     * @param {Mat3} out - Output result matrix. If empty, return the new matrix.
     * @returns {Mat3} - Return output matrix.
     * @static
     * @sdk 11.7.0
     */
    static fromAxisAngle(axis: Vec3, angle: number, out?: Mat3): Mat3;
    private fromToRotation;
    /**
     * @function
     * @name Mat3#fromToRotation
     * @description Calculate rotation from one vector to another.
     * @param {Vec3} from - From axis.
     * @param {Vec3} to - To axis.
     * @param {Mat3} out - Output result matrix. If empty, return the new matrix.
     * @returns {Mat3} - Return output matrix.
     * @static
     * @sdk 11.7.0
     */
    static fromToRotation(from: Vec3, to: Vec3, out?: Mat3): Mat3;
    private fromLookAt;
    /**
     * @function
     * @name Mat3#fromLookAt
     * @description Calculate rotation from look and up vetors.
     * @param {Vec3} target - Target vector.
     * @param {Vec3} up - Up vector.
     * @param {Mat3} out - Output result matrix. If empty, return the new matrix.
     * @returns {Mat3} - Return output matrix.
     * @static
     * @sdk 11.7.0
     */
    static fromLookAt(target: Vec3, up: Vec3, out?: Mat3): Mat3;
    private fromBasisXYZ;
    /**
     * @function
     * @name Mat3#fromBasisXYZ
     * @description Creates a matrix specified by the three provided basis vectors.
     * @param {Vec3} xAxis - X axis.
     * @param {Vec3} yAxis - Y axis.
     * @param {Vec3} zAxis - X axis.
     * @param {Mat3} out - Output result matrix. If empty, return the new matrix.
     * @returns {Mat3} - Return output matrix.
     * @static
     * @sdk 11.7.0
     */
    static fromBasisXYZ(xAxis: Vec3, yAxis: Vec3, zAxis: Vec3, out?: Mat3): Mat3;
    private orthoNormalVectorFast;
    /**
     * @function
     * @name Mat3#orthoNormalize
     * @description Orthonormalizes the matrix.
     * @returns {Mat3} - Self for chaining.
     * @sdk 11.7.0
     */
    orthoNormalize(): Mat3;
    private sanitizeEuler;
    /**
     * @function
     * @name Mat3#toEulerAngles
     * @description Get euler rotation from the matrix.
     * @param {Vec3} output - [optional] Euler angles. Create new ouput if it is not provided.
     * @returns {Mat3} - Output for chaining.
     * @sdk 11.7.0
     */
    toEulerAngles(output?: Vec3): Vec3;
    /**
     * @function
     * @name Mat3#toAxisAngle
     * @description Get euler rotation from the matrix.
     * @param {Vec3} axis - Output rotation axis.
     * @returns {number} - Rotation angle in degrees.
     * @sdk 11.7.0
     */
    toAxisAngle(axis: Vec3): number;
}
