import Matrix from './matrix';
import Amaz = effect.Amaz;
import Vec3 from './vec3';
import Vec4 from './vec4';
import Quat from './quat';
import Mat3 from './mat3';
/**
 * @class
 * @category Math
 * @name Mat4
 * @classdesc Class for math 4x4 column-major matrix.
 * @description Constructor to create an Mat4 instance column by column - initializes as an identity matrix by default.
 * @param {number} m0 - 1st column's 1st element.
 * @param {number} m1 - 1st column's 2nd element.
 * @param {number} m2 - 1st column's 3rd element.
 * @param {number} m3 - 1st column's 4th element.
 * @param {number} m4 - 2nd column's 1st element.
 * @param {number} m5 - 2nd column's 2nd element.
 * @param {number} m6 - 2nd column's 3rd element.
 * @param {number} m7 - 2nd column's 4th element.
 * @param {number} m8 - 3rd column's 1st element.
 * @param {number} m9 - 3rd column's 2nd element.
 * @param {number} m10 - 3rd column's 3rd element.
 * @param {number} m11 - 3rd column's 4th element.
 * @param {number} m12 - 4th column's 1st element.
 * @param {number} m13 - 4th column's 2nd element.
 * @param {number} m14 - 4th column's 3rd element.
 * @param {number} m15 - 4th column's 4th element.
 * @sdk 11.7.0
 */
export default class Mat4 extends Matrix {
    constructor();
    constructor(mat: Amaz.Matrix4x4f);
    constructor(mat: Mat3);
    constructor(m0: number, m1: number, m2: number, m3: number, m4: number, m5: number, m6: number, m7: number, m8: number, m9: number, m10: number, m11: number, m12: number, m13: number, m14: number, m15: number);
    static fromNative(nativeMat: Amaz.Matrix4x4f): Mat4;
    /**
     * @name Mat3#native
     * @type {Amaz.Matrix4x4f}
     * @description Returns the native data structure of Mat4x4.
     * @sdk 11.7.0
     */
    get native(): Amaz.Matrix4x4f;
    /**
     * @function
     * @name Mat4#set
     * @description Set new elements to this matrix.
     * @param {number} row - Row index.
     * @param {number} col - Column index.
     * @param {number} value - Value to be set for the index.
     * @returns {Mat3} - Self for chaining.
     * @sdk 11.7.0
     */
    set(row: number, col: number, value: number): Mat4;
    /**
     * @function
     * @name Mat4#get
     * @description Get value from row and column index.
     * @param {number} row - Row of element.
     * @param {number} col - Column of element.
     * @returns {number} - Value of element.
     * @sdk 11.7.0
     */
    get(row: number, col: number): number;
    /**
     * @function
     * @name Mat4#getRow
     * @description Get rown vector from row index.
     * @param {number} row - Row index.
     * @param {Vec4} out - Optional ouput vector to store result, otherwise a new vector will be created.
     * @returns {Vec4} - Return output for chaining.
     * @sdk 11.7.0
     */
    getRow(row: number, out?: Vec4): Vec4;
    /**
     * @function
     * @name Mat4#setRow
     * @description Set matrix's row from index and input value.
     * @param {number} row - Row index.
     * @param {Vec4} value - Input value.
     * @returns {Mat4} - Return self for chaining.
     * @sdk 11.7.0
     */
    setRow(row: number, value: Vec4): Mat4;
    /**
     * @function
     * @name Mat4#getColumn
     * @description Get column vetor from column index.
     * @param {number} col - Column index.
     * @param {Vec4} out - Optional ouput vector to store result, otherwise a new vector will be created.
     * @returns {Vec4} - Return output for chaining.
     * @sdk 11.7.0
     */
    getColumn(col: number, out?: Vec4): Vec4;
    /**
     * @function
     * @name Mat4#setColumn
     * @description Set matrix's column from index and input value.
     * @param {number} col - Column index.
     * @param {Vec4} value - Input value.
     * @returns {Mat4} - Return self for chaining.
     * @sdk 11.7.0
     */
    setColumn(col: number, value: Vec4): Mat4;
    /**
     * @function
     * @name Mat4#getAxisX
     * @description Get axis X vector.
     * @param {Vec3} out - Optional ouput vector to store result, otherwise a new vector will be created.
     * @returns {Vec3} - Return output for chaining.
     * @sdk 11.7.0
     */
    getAxisX(out?: Vec3): Vec3;
    /**
     * @function
     * @name Mat4#setAxisX
     * @description Set matrix's axis X from input value.
     * @param {Vec3} value - Input value.
     * @returns {Mat4} - Return self for chaining.
     * @sdk 11.7.0
     */
    setAxisX(value: Vec3): Mat4;
    /**
     * @function
     * @name Mat4#getAxisY
     * @description Get axis Y vector.
     * @param {Vec3} out - Optional ouput vector to store result, otherwise a new vector will be created.
     * @returns {Vec3} - Return output for chaining.
     * @sdk 11.7.0
     */
    getAxisY(out?: Vec3): Vec3;
    /**
     * @function
     * @name Mat4#setAxisY
     * @description Set matrix's axis Y from input value.
     * @param {Vec3} value - Input value.
     * @returns {Mat4} - Return self for chaining.
     * @sdk 11.7.0
     */
    setAxisY(value: Vec3): Mat4;
    /**
     * @function
     * @name Mat4#getAxisZ
     * @description Get axis Z vector.
     * @param {Vec3} out - Optional ouput vector to store result, otherwise a new vector will be created.
     * @returns {Vec3} - Return output for chaining.
     * @sdk 11.7.0
     */
    getAxisZ(out?: Vec3): Vec3;
    /**
     * @function
     * @name Mat4#setAxisZ
     * @description Set matrix's axis Z from input value.
     * @param {Vec3} value - Input value.
     * @returns {Mat4} - Return self for chaining.
     * @sdk 11.7.0
     */
    setAxisZ(value: Vec3): Mat4;
    /**
     * @function
     * @name Mat4#getTranslation
     * @description Get the translation vector.
     * @param {Vec3} out - Optional ouput vector to store result, otherwise a new vector will be created.
     * @returns {Vec3} - Return output for chaining.
     * @sdk 11.7.0
     */
    getTranslation(out?: Vec3): Vec3;
    /**
     * @function
     * @name Mat4#setTranslation
     * @description Set matrix's translation from input value.
     * @param {Vec3} value - Input value.
     * @returns {Mat4} - Return self for chaining.
     * @sdk 11.7.0
     */
    setTranslation(value: Vec3): Mat4;
    /**
     * @function
     * @name Mat4#copy
     * @description Copy the elements from target to this object.
     * @param {Mat4} target - Target.
     * @returns {Mat4} - Self for chaining.
     * @sdk 11.7.0
     */
    copy(target: Mat4): Mat4;
    /**
     * @function
     * @name Mat4#clone
     * @description Returns an identical copy of this object.
     * @returns {Mat4} The cloned instance.
     * @sdk 11.7.0
     */
    clone(): Mat4;
    /**
     * @function
     * @name Mat4#eq
     * @description Checks strict equality of this matrix and other matrix.
     * @param {Mat4} other - Other matrix.
     * @returns {boolean} - Returns true if the matrix are equal and false otherwise.
     * @sdk 11.7.0
     */
    eq(other: Mat4): boolean;
    /**
     * @function
     * @name Mat4#eq
     * @description Checks strict equality of this matrix and other matrix.
     * @param {Mat4} m0 - 1 matrix.
     * @param {Mat4} m1 - 2 matrix.
     * @returns {boolean} - Returns true if the matrices are equal and false otherwise.
     * @static
     * @sdk 11.7.0
     */
    static eq(m0: Mat4, m1: Mat4): boolean;
    /**
     * @function
     * @name Mat4#identity
     * @description Reset to identity matrix.
     * @returns {Mat4} - Self for chaining.
     * @sdk 11.7.0
     */
    identity(): Mat4;
    /**
     * @function
     * @name Mat4#zero
     * @description Reset to zero matrix.
     * @returns {Mat4} - Self for chaining.
     * @sdk 11.7.0
     */
    zero(): Mat4;
    /**
     * @function
     * @name Mat4#isIdentity
     * @description Check if this is an identity matrix.
     * @param {number} epsilon - Epsilon number.
     * @returns {boolean} - True if it is an identity matrix.
     * @sdk 11.7.0
     */
    isIdentity(epsilon?: number): boolean;
    /**
     * @function
     * @name Mat4#isZero
     * @description Check if this is a zero matrix.
     * @param {number} epsilon - Epsilon number.
     * @returns {boolean} - True if it is an zero matrix.
     * @sdk 11.7.0
     */
    isZero(epsilon?: number): boolean;
    private toArrayCopy;
    /**
     * @function
     * @name Mat4#invTRS
     * @description Inverse transform matrix (Rotation, Scale, Translation).
     * @returns {Mat4} Self for chaining.
     * @sdk 11.7.0
     */
    invTRS(): Mat4;
    /**
     * @function
     * @name Mat4#inv
     * @description Inverse full matrix.
     * @returns {Mat4} Self for chaining.
     * @sdk 11.7.0
     */
    inv(): Mat4;
    /**
     * @function
     * @name Mat4#mul
     * @description Use this Matrix to multiply other matrix.
     * @param {Mat4} target Other matrix.
     * @returns {Mat4} Return self for chaining.
     * @sdk 11.7.0
     */
    mul(target: Mat4): Mat4;
    private transformVec4;
    /**
     * @function
     * @name Mat4#transformVec4
     * @description Multiplies matrix and vector4.
     * @param {Mat4} m - Matrix.
     * @param {Vec4} inV - Vector to be multiplied.
     * @returns {Vec4} - Returns input Vector for chaining.
     * @static
     * @sdk 11.7.0
     */
    static transformVec4(m: Mat4, inV: Vec4): Vec4;
    private rotateQuat;
    /**
     * @function
     * @name Mat4#rotateQuat
     * @description Multiplies matrix and quaternion.
     * @param {Mat4} m - Matrix.
     * @param {Quat} inQ - Quat to be multiplied.
     * @returns {Quat} - Returns input quat for chaining.
     * @static
     * @sdk 11.7.0
     */
    static rotateQuat(m: Mat4, inQ: Quat): Quat;
    private transformVec3;
    /**
     * @function
     * @name Mat4#transformVec3
     * @description Multiplies matrix and vector3.
     * @param {Mat4} m - Matrix.
     * @param {Vec3} inV - Vector to be multiplied.
     * @returns {Vec3} - Returns input Vector for chaining.
     * @static
     * @sdk 11.7.0
     */
    static transformVec3(m: Mat4, inV: Vec3): Vec3;
    /**
     * @function
     * @name Mat4#scale
     * @description Scale this matrix along X-axis, Y-axis and Z-axis by factor vector.
     * @param {Vec3} factor Factor vector.
     * @returns {Mat4} Self for chaining.
     * @sdk 11.7.0
     */
    scale(factor: Vec3): Mat4;
    /**
     * @function
     * @name Mat4#determinant
     * @description Computes and returns the determinant of this matrix.
     * @returns {number} Determinant of the matrix.
     * @sdk 11.7.0
     */
    determinant(): number;
    /**
     * @function
     * @name Mat4#transpose
     * @description Transpose the matrix.
     * @returns {Mat4} Self for chaining.
     * @sdk 11.7.0
     */
    transpose(): Mat4;
    private fromToRotation;
    /**
     * @function
     * @name Mat4#fromToRotation
     * @description Calculate rotation from one vector to another.
     * @param {Vec3} from - From axis.
     * @param {Vec3} to - To axis.
     * @param {Mat4} out - Output Result matrix. If empty, return the new matrix.
     * @returns {Mat4} - Return output matrix.
     * @static
     * @sdk 11.7.0
     */
    static fromToRotation(from: Vec3, to: Vec3, out?: Mat4): Mat4;
    private fromBasisXYZ;
    /**
     * @function
     * @name Mat4#fromBasisXYZ
     * @description Creates a matrix specified by the three provided basis vectors.
     * @param {Vec3} xAxis - X axis.
     * @param {Vec3} yAxis - Y axis.
     * @param {Vec3} zAxis - X axis.
     * @param {Mat4} out - Output Result matrix. If empty, return the new matrix.
     * @returns {Mat4} - Return output matrix.
     * @static
     * @sdk 11.7.0
     */
    static fromBasisXYZ(xAxis: Vec3, yAxis: Vec3, zAxis: Vec3, out?: Mat4): Mat4;
    private fromOrtho;
    /**
     * @function
     * @name Mat4#fromOrtho
     * @description Creates an orthographic projection matrix.
     * @param {number} left - The x-coordinate for the left edge of the near projection plane in view space.
     * @param {number} right - The x-coordinate for the right edge of the near projection plane in view space.
     * @param {number} bottom - The y-coordinate for the bottom edge of the near projection plane in view space.
     * @param {number} top - The y-coordinate for the top edge of the near projection plane in view space.
     * @param {number} near - The distance to the near clipping plane in view space.
     * @param {number} far - The distance to the far clipping plane in view space.
     * @param {Mat4} out - Output Result matrix. If empty, return the new matrix.
     * @returns {Mat4} - Return output matrix.
     * @static
     * @sdk 11.7.0
     */
    static fromOrtho(left: number, right: number, bottom: number, top: number, near: number, far: number, out?: Mat4): Mat4;
    private fromFrustum;
    /**
     * @function
     * @name Mat4#fromFrustum
     * @description Creates a perspective projection matrix.
     * @param {number} left - The x-coordinate for the left edge of the near projection plane in view space.
     * @param {number} right - The x-coordinate for the right edge of the near projection plane in view space.
     * @param {number} bottom - The y-coordinate for the bottom edge of the near projection plane in view space.
     * @param {number} top - The y-coordinate for the top edge of the near projection plane in view space.
     * @param {number} near - The distance to the near clipping plane in view space.
     * @param {number} far - The distance to the far clipping plane in view space.
     * @param {Mat4} out - Output Result matrix. If empty, return the new matrix.
     * @returns {Mat4} - Return output matrix.
     * @static
     * @sdk 11.7.0
     */
    static fromFrustum(left: number, right: number, bottom: number, top: number, near: number, far: number, out?: Mat4): Mat4;
    private fromPerspective;
    /**
     * @function
     * @name Mat4#fromPerspective
     * @description Creates a perspective projection matrix.
     * @param {number} fovy - The frustum's field of view in degree.
     * @param {number} aspect - The aspect ratio.
     * @param {number} near - The distance to the near clipping plane in view space.
     * @param {number} far - The distance to the far clipping plane in view space.
     * @param {Mat4} out - Output Result matrix. If empty, return the new matrix.
     * @returns {Mat4} - Return output matrix.
     * @static
     * @sdk 11.7.0
     */
    static fromPerspective(fovy: number, aspect: number, near: number, far: number, out?: Mat4): Mat4;
    /**
     * @function
     * @name Mat4#fromTranslation
     * @description Create translation matrix.
     * @param {number} x - X value.
     * @param {number} y - Y value.
     * @param {number} z - X value.
     * @param {Mat3} out - Output result matrix. If empty, return the new matrix.
     * @returns {Mat4} - return output matrix.
     * @static
     * @sdk 11.7.0
     */
    static fromTranslation(x: number, y: number, z: number, out?: Mat4): Mat4;
    private fromQuaternion;
    /**
     * @function
     * @name Mat4#fromQuaternion
     * @description Converts quaternion to matrix - filling itself.
     * @param {Quat} q - Quaternion to be converted.
     * @param {Mat4} out - Output Result matrix. If empty, return the new matrix.
     * @returns {Mat4} - Return output matrix.
     * @static
     * @sdk 11.7.0
     */
    static fromQuaternion(q: Quat, out?: Mat4): Mat4;
    private fromRotation;
    /**
     * @function
     * @name Mat4#fromRotation
     * @description Create rotation matrix.
     * @param {Quat} q - Rotation quaternion.
     * @param {Mat4} out - Output Result matrix. If empty, return the new matrix.
     * @returns {Mat4} - Return output matrix.
     * @static
     * @sdk 11.7.0
     */
    static fromRotation(q: Quat, out?: Mat4): Mat4;
    private fromCompose;
    /**
     * @function
     * @name Mat4#fromCompose
     * @description Create matrix from translation, rotation, scale.
     * @param {Vec3} t - Translation vector.
     * @param {Quat} r - Rotation quaternion.
     * @param {Vec3} s - Scale vector.
     * @param {Mat4} out - Output Result matrix. If empty, return the new matrix.
     * @returns {Mat4} - Return output matrix.
     * @static
     * @sdk 11.7.0
     */
    static fromCompose(t: Vec3, r: Quat, s: Vec3, out?: Mat4): Mat4;
    /**
     * @function
     * @name Mat4#decompose
     * @description Get translation, scale, rotation components from matrix.
     * @param {Vec3} t - [output] Translation vector.
     * @param {Quat} r - [output] Scale vector.
     * @param {Vec3} s - [output] Rotation quaternion.
     * @returns {Mat4} - Self for chaining.
     * @sdk 11.7.0
     */
    decompose(t: Vec3, r: Quat, s: Vec3): Mat4;
}
