import Vector from './vector';
import Amaz = effect.Amaz;
import Vec3 from './vec3';
import Mat3 from './mat3';
import Mat4 from './mat4';
/**
 * @class
 * @category Math
 * @name Quat
 * @classdesc Class for quaternions used to represent rotations.
 * @description Constructor to create an instance.
 * @param {number} x - x element defaults to 0.
 * @param {number} y - y element defaults to 0.
 * @param {number} z - z element defaults to 0.
 * @param {number} w - w element defaults to 1.
 * @sdk 11.7.0
 */
export default class Quat extends Vector {
    constructor();
    constructor(x: number, y: number, z: number, w: number);
    constructor(vec: Amaz.Quaternionf);
    static fromNative(nativeVec: Amaz.Quaternionf): Quat;
    /**
     * @function
     * @name Quat#identity
     * @description Get the quaternion of identity rotation.
     * @returns {Quat} - The quaternion of identity rotation.
     * @static
     * @sdk 11.7.0
     */
    static identity(): Quat;
    /**
     * @function
     * @name Quat#fromToRotation
     * @description Generates a quaternion that rotates lhs into rhs.
     * @param {Vec3} from - Direction of from.
     * @param {Vec3} to - Direction of to.
     * @param {Quat} out - Output Result quaternion. If empty, return the new quaternion.
     * @returns {Quat} - Result quaternion.
     * @static
     * @sdk 11.7.0
     */
    static fromToRotation(from: Vec3, to: Vec3, out?: Quat): Quat;
    /**
     * @function
     * @name Quat#fromLookAt
     * @description Generates a Right handed quaternion from a look rotation. Returns if conversion was successful.
     * @param {Vec3} target - Target vector of input look rotation.
     * @param {Vec3} up - Up vector of input look rotation.
     * @param {Quat} out - Output Result quaternion. If empty, return the new quaternion.
     * @returns {Quat} - Result quaternion.
     * @static
     * @sdk 11.7.0
     */
    static fromLookAt(target: Vec3, up: Vec3, out?: Quat): Quat;
    /**
     * @function
     * @name Quat#rotateVec3
     * @description Rotate vector rhs by input quaternion.
     * @param {Quat} quat - Input rotation quternion.
     * @param {Vec3} v - Input rotation vector.
     * @returns {Vec3} - Result rotation vector.
     * @static
     * @sdk 11.7.0
     */
    static rotateVec3(quat: Quat, v: Vec3): Vec3;
    /**
     * @function
     * @name Quat#slerp
     * @description Calculates the spherically interpolation between two quaternions (Factor 0.0 - 1.0).
     * @param {Quat} q1 - 1st quaternion.
     * @param {Quat} q2 - 2nd quaternion.
     * @param {number} t - Factor will be clamped to 0.0 - 1.0.
     * @param {Quat} out - Output Result quaternion. If empty, return the new quaternion.
     * @returns {Quat} - Return output quaternion.
     * @static
     * @sdk 11.7.0
     */
    static slerp(q1: Quat, q2: Quat, t: number, out?: Quat): Quat;
    /**
     * @function
     * @name Quat#fromAxisAngle
     * @description Converts angle-axis to quaternion representation.
     * @param {Vec3} axis - Input rotation axis.
     * @param {number} angle - Roation angle around axis (in degrees).
     * @param {Quat} out - Output Result quaternion. If empty, return the new quaternion.
     * @returns {Quat} - Output quaternion.
     * @static
     * @sdk 11.7.0
     */
    static fromAxisAngle(axis: Vec3, angle: number, out?: Quat): Quat;
    /**
     * @function
     * @name Quat#eq
     * @description Judge whether the value of current quaternion is equal to other quaternion.
     * @param {Quat} q0 - A quaternion.
     * @param {Quat} q1 - Other quaternion.
     * @returns {boolean} - Returns true if the quaternion are equal and false otherwise.
     * @static
     * @sdk 11.7.0
     */
    static eq(q0: Quat, q1: Quat): boolean;
    /**
     * @name Quat#native
     * @type {Amaz.Quaternionf}
     * @description Returns the native data structure of quaternion.
     * @sdk 11.7.0
     */
    get native(): Amaz.Quaternionf;
    /**
     * @function
     * @name Quat#set
     * @description Set new elements to this quaternion.
     * @param {number} x - x element.
     * @param {number} y - y element.
     * @param {number} z - z element.
     * @param {number} w - w element.
     * @returns {Quat} - Self for chaining.
     * @sdk 11.7.0
     */
    set(x: number, y: number, z: number, w: number): Quat;
    /**
     * @name Quat#x
     * @type {number}
     * @description x element.
     * @sdk 11.7.0
     */
    get x(): number;
    set x(value: number);
    /**
     * @name Quat#y
     * @type {number}
     * @description y element.
     * @sdk 11.7.0
     */
    get y(): number;
    set y(value: number);
    /**
     * @name Quat#z
     * @type {number}
     * @description z element.
     * @sdk 11.7.0
     */
    get z(): number;
    set z(value: number);
    /**
     * @name Quat#w
     * @type {number}
     * @description w element.
     * @sdk 11.7.0
     */
    get w(): number;
    set w(value: number);
    /**
     * @function
     * @name Quat#eq
     * @description Judge whether the value of current quaternion is equal to other quaternion.
     * @param {Quat} other - Other quaternion.
     * @returns {boolean} - Returns true if the quaternion are equal and false otherwise.
     * @static
     * @sdk 11.7.0
     */
    eq(other: Quat): boolean;
    /**
     * @function
     * @name Quat#toString
     * @description Return current quaternion value in string.
     * @returns {string} - Current quaternion value in string.
     * @sdk 11.7.0
     */
    toString(): string;
    /**
     * @function
     * @name Quat#add
     * @description Add other quaternion to this quaternion.
     * @param {Quat} v0 - Other quaternion.
     * @returns {Quat} - Self for chaining.
     * @sdk 11.7.0
     */
    add(v0: Quat): Quat;
    /**
     * @function
     * @name Quat#sub
     * @description Subtract other quaternion from this quaternion.
     * @param {Quat} v0 - Other quaternion.
     * @returns {Quat} - Self for chaining.
     * @sdk 11.7.0
     */
    sub(v0: Quat): Quat;
    /**
     * @function
     * @name Quat#mul
     * @description Use this quaternion to rotate other quaternion.
     * @param {Quat} target Other quaternion.
     * @returns {Quat} Self for chaining.
     * @sdk 11.7.0
     */
    mul(target: Quat): Quat;
    /**
     * @function
     * @name Quat#div
     * @description Divide each element by number.
     * @param {number} num - Number to divide.
     * @returns {Quat} - Self for chaining.
     * @sdk 11.7.0
     */
    div(num: number): Quat;
    /**
     * @function
     * @name Quat#neg
     * @description Negates each element of this quaternion.
     * @returns {Quat} - Self for chaining.
     * @sdk 11.7.0
     */
    neg(): Quat;
    /**
     * @function
     * @name Quat#identity
     * @description Get the quaternion of identity rotation.
     * @returns {Quat} - The quaternion of identity rotation.
     * @sdk 11.7.0
     */
    identity(): Quat;
    /**
     * @function
     * @name Quat#fromEulerAngles
     * @description Convert euler angles to quaternion.
     * @param {number} x - Angle around X (in degrees).
     * @param {number} y - Angle around Y (in degrees).
     * @param {number} z - Angle around Z (in degrees).
     * @param {Quat} out - Output result quaternion. If empty, return the new quaternion.
     * @returns {Quat} - Output quaternion.
     * @static
     * @sdk 11.7.0
     */
    static fromEulerAngles(x: number, y: number, z: number, out?: Quat): Quat;
    /**
     * @function
     * @name Quat#copy
     * @description Copy the elements from target to this object.
     * @param {Quat} q - Target.
     * @returns {Quat} - Self for chaining.
     * @sdk 11.7.0
     */
    copy(q: Quat): Quat;
    /**
     * @function
     * @name Quat#clone
     * @description Returns an identical copy of this object.
     * @returns {Quat} The cloned instance.
     * @sdk 11.7.0
     */
    clone(): Quat;
    /**
     * @function
     * @name Quat#toEulerAngles
     * @param {Vec3} eulerAngles - Result euler angles.
     * @description Convert quaternion to euler angles (in degrees).
     * @returns {Vec3} - Result for chaining.
     * @sdk 11.7.0
     */
    toEulerAngles(eulerAngles: Vec3): Vec3;
    /**
     * @function
     * @name Quat#toAxisAngle
     * @description Convert quaternion to axis and rotation angle.
     * @param {Vec3} axis - Result axis.
     * @returns {number} - Rotation angle (in degrees).
     * @sdk 11.7.0
     */
    toAxisAngle(axis: Vec3): number;
    private rotateVec3;
    private fromAxisAngle;
    /**
     * @function
     * @name Quat#normalize
     * @description Converts input quaternion to one with the same orientation but with a len of 1.
     * @returns {Quat} - Normalized quaternion.
     * @sdk 11.7.0
     */
    normalize(): Quat;
    /**
     * @function
     * @name Quat#setZero
     * @description Set elements in current quaternion to 0.
     * @returns {Quat} - Zero quaternion.
     * @sdk 11.7.0
     */
    setZero(): Quat;
    /**
     * @function
     * @name Quat#len
     * @description Get the len of input quaternion.
     * @returns {number} - Magnitude of input quaternion.
     * @sdk 11.7.0
     */
    len(): number;
    /**
     * @function
     * @name Quat#len
     * @description Get the sqrt len of input quaternion.
     * @returns {number} - Sqrt len of input quaternion.
     * @sdk 11.7.0
     */
    lenSq(): number;
    /**
     * @function
     * @name Quat#inv
     * @description Inverse quaternion. Should be used for normalized rotation quaternion.
     * @returns {Quat} - Inverse quaternion of input quaternion.
     * @sdk 11.7.0
     */
    inv(): Quat;
    /**
     * @function
     * @name Quat#fromMatrix4
     * @description Converts input matrix4 m to quaternion.
     * @param {Mat4} m - Input matrix.
     * @param {Quat} out - Output Result quaternion. If empty, return the new quaternion.
     * @returns {Quat} - Output quaternion representation of input matrix.
     * @static
     * @sdk 11.7.0
     */
    static fromMatrix4(m: Mat4, out?: Quat): Quat;
    private indexSet;
    /**
     * @function
     * @name Quat#fromMatrix3
     * @description Converts input matrix3 m to quaternion.
     * @param {Mat3} kRot - Input matrix.
     * @param {Quat} out - Output Result quaternion. If empty, return the new quaternion.
     * @returns {Quat} - Output quaternion representation of input matrix.
     * @sdk 11.7.0
     */
    static fromMatrix3(kRot: Mat3, out?: Quat): Quat;
    private fromMatrix3;
}
