import Vector from './vector';
import Amaz = effect.Amaz;
/**
 * @class
 * @category Math
 * @name Vec2
 * @classdesc Class for a 2-dimensional math vector.
 * @description Constructor to create an instance.
 * @param {number} x - x element defaults to 0.
 * @param {number} y - y element defaults to 0.
 * @sdk 11.7.0
 */
export default class Vec2 extends Vector {
    constructor();
    constructor(x: number, y: number);
    constructor(vec: Amaz.Vector2f);
    static fromNative(nativeVec: Amaz.Vector2f): Vec2;
    /**
     * @function
     * @name Vec2#eq
     * @description Judge whether the value of current Vector2 is equal to other Vector2.
     * @param {Vec2} v0 - A Vector2.
     * @param {Vec2} v1 - Other Vector2.
     * @returns {boolean} - Returns true if the Vector2 are equal and false otherwise.
     * @static
     * @sdk 11.7.0
     */
    static eq(v0: Vec2, v1: Vec2): boolean;
    /**
     * @name Vec2#native
     * @type {Amaz.Vector2f}
     * @description Returns the native data structure of vector2.
     * @sdk 11.7.0
     */
    get native(): Amaz.Vector2f;
    /**
     * @function
     * @name Vec2#set
     * @description Set new elements to this vector.
     * @param {number} x - x element.
     * @param {number} y - y element.
     * @returns {Vec2} - Self for chaining.
     * @sdk 11.7.0
     */
    set(x: number, y: number): Vec2;
    /**
     * @name Vec2#x
     * @type {number}
     * @description x element.
     * @sdk 11.7.0
     */
    get x(): number;
    set x(value: number);
    /**
     * @name Vec2#y
     * @type {number}
     * @description y element.
     * @sdk 11.7.0
     */
    get y(): number;
    set y(value: number);
    /**
     * @function
     * @name Vec2#copy
     * @description Copy the elements from target to this object.
     * @param {Vec2} target - Target vector.
     * @returns {Vec2} - Self for chaining.
     * @sdk 11.7.0
     */
    copy(target: Vec2): Vec2;
    /**
     * @function
     * @name Vec2#clone
     * @description Returns an identical copy of this object.
     * @returns {Vec2} The cloned instance.
     * @sdk 11.7.0
     */
    clone(): Vec2;
    /**
     * @function
     * @name Vec2#add
     * @description Add other vector to this vector.
     * @param {Vec2} other - Other vector.
     * @returns {Vec2} - Self for chaining.
     * @sdk 11.7.0
     */
    add(other: Vec2): Vec2;
    /**
     * @function
     * @name Vec2#sub
     * @description Subtract other from this vector.
     * @param {Vec2} other - 1st vector.
     * @returns {Vec2} - Self for chaining.
     * @sdk 11.7.0
     */
    sub(other: Vec2): Vec2;
    /**
     * @function
     * @name Vec2#mul
     * @description Multiply this vector by scalar or scalar vector.
     * Result: this = this * scalar or this = this * scalarVector.
     * @param {Vec2 | number} scale scalar or scalar vector.
     * @returns {Vec2} Self for chaining.
     * @sdk 11.7.0
     */
    mul(scale: number | Vec2): Vec2;
    /**
     * @function
     * @name Vec2#div
     * @description Divide this vector by divisor or divisor vector.
     * Result: this = this / divisor or this = this / divisorVector.
     * @param {Vec2 | number} divisor divisor or divisor vector.
     * @returns {Vec2} Self for chaining.
     * @sdk 11.7.0
     */
    div(divisor: number | Vec2): Vec2;
    /**
     * @function
     * @name Vec2#eq
     * @description Checks strict equality of this vector and other vector.
     * @param {Vec2} other - Other vector.
     * @returns {boolean} - Returns true if the vectors are equal and false otherwise.
     * @sdk 11.7.0
     */
    eq(other: Vec2): boolean;
    /**
     * @function
     * @name Vec2#neg
     * @description Negates each element of this vector.
     * @returns {Vec2} Self for chaining.
     * @sdk 11.7.0
     */
    neg(): Vec2;
    /**
     * @function
     * @name Vec2#inv
     * @description Make each element equal to 1.0 divided by itself in this vector.
     * @returns {Vec2} - Self for chaining.
     * @sdk 11.7.0
     */
    inv(): Vec2;
    /**
     * @function
     * @name Vec2#dot
     * @description Calculate dot product of 2 vectors.
     * @param {Vec2} other - Other vector.
     * @returns {number} - Returns dot product.
     * @sdk 11.7.0
     */
    dot(other: Vec2): number;
    /**
     * @function
     * @name Vec2#len
     * @description Calculate length of this vector.
     * @returns {number} - Returns length.
     * @sdk 11.7.0
     */
    len(): number;
    /**
     * @function
     * @name Vec2#sqrMagnitude
     * @description Calculate squared length of this vector.
     * @returns {number} - Returns squared length.
     * @sdk 11.7.0
     */
    lenSq(): number;
    /**
     * @function
     * @name Vec2#angle
     * @description Calculate the angle in degrees of this vector with respect to the other vector.
     * @param {Vec2} other - Other vector.
     * @returns {number} - Returns the angle in degrees.
     * @sdk 11.7.0
     */
    angle(other: Vec2): number;
    /**
     * @function
     * @name Vec2#normalize
     * @description Converts this vector to a normalized vector.
     * @returns {Vec2} Self for chaining.
     * @sdk 11.7.0
     */
    normalize(): Vec2;
    /**
     * @function
     * @name Vec2#isNormalized
     * @description Checks if this vector is a length one vector.
     * @returns {boolean} Returns true if it is and false otherwise.
     * @sdk 11.7.0
     */
    isNormalized(): boolean;
    /**
     * @function
     * @name Vec2#max
     * @description Returns this vector with the larger of every element from the v0 and v1 vectors.
     * @param {Vec2} v0 - 1st vector.
     * @param {Vec2} v1 - 2nd vector.
     * @returns {Vec2} - Self for chaining.
     * @sdk 11.7.0
     */
    max(v0: Vec2, v1: Vec2): Vec2;
    /**
     * @function
     * @name Vec2#min
     * @description Returns this vector with the smaller of every element from the v0 and v1 vectors.
     * @param {Vec2} v0 - 1st vector.
     * @param {Vec2} v1 - 2nd vector.
     * @returns {Vec2} - Self for chaining.
     * @sdk 11.7.0
     */
    min(v0: Vec2, v1: Vec2): Vec2;
    /**
     * @function
     * @name Vec2#abs
     * @description Calculate the absolute values of every element for this vector.
     * @returns {Vec2} - Self for chaining.
     * @sdk 11.7.0
     */
    abs(): Vec2;
    /**
     * @function
     * @name Vec2#lerp
     * @description Calculates the linear interpolation between two vectors (Factor 0.0 - 1.0).
     * @param {Vec2} v0 - 1st vector.
     * @param {Vec2} v1 - 2nd vector.
     * @param {number} t - Factor will be clamped to 0.0 - 1.0.
     * @param {Vec2} out - output vector.
     * @returns {Vec2} - Self for chaining.
     * @static
     * @sdk 11.7.0
     */
    static lerp(v0: Vec2, v1: Vec2, t: number, out?: Vec2): Vec2;
    /**
     * @function
     * @name Vec2#distance
     * @description Calculate the distance from this vector to the other.
     * @param {Vec2} other - Other vector.
     * @returns {Vec2} - Returns the distance.
     * @sdk 11.7.0
     */
    distance(other: Vec2): number;
    /**
     * @function
     * @name Vec2#isFinite
     * @description Determine whether this vector is finite.
     * @returns {boolean} - Returns true if it is and false otherwise.
     * @sdk 11.7.0
     */
    isFinite(): boolean;
    /**
     * @function
     * @name Vec2#toString
     * @description Return current vector value in string.
     * @returns {string} - Current vector value in string.
     * @sdk 11.7.0
     */
    toString(): string;
    /**
     * @function
     * @name Vec2#aboutEq
     * @description Determine if two vector2 are approximately equal.
     * @param {Vec2} other - Other vector.
     * @param {number} epsilon - Epsilon.
     * @returns {boolean} - Returns true if they are approximately equal.
     * @sdk 11.7.0
     */
    aboutEq(other: Vec2, epsilon?: number): boolean;
}
