import Vector from './vector';
import Amaz = effect.Amaz;
/**
 * @class
 * @category Math
 * @name Vec3
 * @classdesc Class for a 3-dimensional math vector.
 * @description Constructor to create an instance.
 * @param {number} x - x element defaults to 0.
 * @param {number} y - y element defaults to 0.
 * @param {number} z - z element defaults to 0.
 * @sdk 11.7.0
 */
export default class Vec3 extends Vector {
    constructor();
    constructor(x: number, y: number, z: number);
    constructor(vec: Amaz.Vector3f);
    static fromNative(nativeVec: Amaz.Vector3f): Vec3;
    /**
     * @function
     * @name Vec3#eq
     * @description Judge whether the value of current vector3 is equal to other vector3.
     * @param {Vec3} v0 - A vector3.
     * @param {Vec3} v1 - Other vector3.
     * @returns {boolean} - Returns true if the vector3 are equal and false otherwise.
     * @static
     * @sdk 11.7.0
     */
    static eq(v0: Vec3, v1: Vec3): boolean;
    /**
     * @name Vec3#native
     * @type {Amaz.Vector3f}
     * @description Returns the native data structure of vector3f.
     * @sdk 11.7.0
     */
    get native(): Amaz.Vector3f;
    /**
     * @function
     * @name Vec3#set
     * @description Set new elements to this vector.
     * @param {number} x - x element.
     * @param {number} y - y element.
     * @param {number} z - z element.
     * @returns {Vec3} - Self for chaining.
     * @sdk 11.7.0
     */
    set(x: number, y: number, z: number): Vec3;
    /**
     * @name Vec3#x
     * @type {number}
     * @description x element.
     * @sdk 11.7.0
     */
    get x(): number;
    set x(value: number);
    /**
     * @name Vec3#y
     * @type {number}
     * @description y element.
     * @sdk 11.7.0
     */
    get y(): number;
    set y(value: number);
    /**
     * @name Vec3#z
     * @type {number}
     * @description z element.
     * @sdk 11.7.0
     */
    get z(): number;
    set z(value: number);
    /**
     * @function
     * @name Vec3#copy
     * @description Copy the elements from target to this object.
     * @param {Vec3} target - Target.
     * @returns {Vec3} - Self for chaining.
     * @sdk 11.7.0
     */
    copy(target: Vec3): Vec3;
    /**
     * @function
     * @name Vec3#clone
     * @description Returns an identical copy of this object.
     * @returns {Vec3} The cloned instance.
     * @sdk 11.7.0
     */
    clone(): Vec3;
    /**
     * @function
     * @name Vec3#add
     * @description Add other vector to this vector.
     * @param {Vec3} other - 1st vector.
     * @returns {Vec3} - Self for chaining.
     * @sdk 11.7.0
     */
    add(other: Vec3): Vec3;
    /**
     * @function
     * @name Vec3#sub
     * @description Subtract other vector to this vector.
     * @param {Vec3} other - 1st vector.
     * @returns {Vec3} - Self for chaining.
     * @sdk 11.7.0
     */
    sub(other: Vec3): Vec3;
    /**
     * @function
     * @name Vec3#mul
     * @description Multiply this vector by scalar or scalar vector.
     * Result: this = this * scalar or this = this * scalarVector.
     * @param {Vec3 | number} scale scalar or scalar vector.
     * @returns {Vec3} Self for chaining.
     * @sdk 11.7.0
     */
    mul(scale: number | Vec3): Vec3;
    /**
     * @function
     * @name Vec3#div
     * @description Divide this vector by divisor or divisor vector.
     * Result: this = this / divisor or this = this / divisorVector.
     * @param {Vec3 | number} divisor divisor or divisor vector.
     * @returns {Vec3} Self for chaining.
     * @sdk 11.7.0
     */
    div(divisor: number | Vec3): Vec3;
    /**
     * @function
     * @name Vec3#eq
     * @description Checks if this vector and other vector are the same vector
     * @param {Vec3} other - Other vector.
     * @returns {boolean} - Returns true if the vectors are equal and false otherwise.
     * @sdk 11.7.0
     */
    eq(other: Vec3): boolean;
    /**
     * @function
     * @name Vec3#neg
     * @description Negate each element of this vector.
     * @returns {Vec3} - Self for chaining.
     * @sdk 11.7.0
     */
    neg(): Vec3;
    /**
     * @function
     * @name Vec3#inv
     * @description Make each element equal to 1.0 divided by itself in this vector.
     * @returns {Vec3} - Self for chaining.
     * @sdk 11.7.0
     */
    inv(): Vec3;
    /**
     * @function
     * @name Vec3#scale
     * @description Scales each element of this vector by corresponding element of the supplied scaler vector.
     * @param {Vec3} factor - Factor to scale.
     * @returns {Vec3} - Self for chaining.
     * @sdk 11.7.0
     */
    scale(factor: Vec3): Vec3;
    /**
     * @function
     * @name Vec3#dot
     * @description Calculate dot product of 2 vectors.
     * @param {Vec3} other - Other vector.
     * @returns {number} - Returns dot product.
     * @sdk 11.7.0
     */
    dot(other: Vec3): number;
    /**
     * @function
     * @name Vec3#len
     * @description Calculate length of this vector.
     * @returns {number} - Returns length.
     * @sdk 11.7.0
     */
    len(): number;
    /**
     * @function
     * @name Vec3#lenSq
     * @description Calculate squared length of this vector.
     * @returns {number} - Returns squared length.
     * @sdk 11.7.0
     */
    lenSq(): number;
    /**
     * @function
     * @name Vec3#normalize
     * @description Converts this vector to a normalized vector.
     * @returns {Vec3} - Self for chaining.
     * @sdk 11.7.0
     */
    normalize(): Vec3;
    /**
     * @function
     * @name Vec3#isNormalized
     * @description Checks if this vector is a normalized vector.
     * @returns {boolean} - Returns true if it is and false otherwise.
     * @sdk 11.7.0
     */
    isNormalized(): boolean;
    /**
     * @function
     * @name Vec3#max
     * @description Returns this vector with the larger of every element from the v0 and v1 vectors.
     * @param {Vec3} v0 - 1st vector.
     * @param {Vec3} v1 - 2nd vector.
     * @returns {Vec3} - Self for chaining.
     * @sdk 11.7.0
     */
    max(v0: Vec3, v1: Vec3): Vec3;
    /**
     * @function
     * @name Vec3#min
     * @description Returns this vector with the smaller of every element from the v0 and v1 vectors.
     * @param {Vec3} v0 - 1st vector.
     * @param {Vec3} v1 - 2nd vector.
     * @returns {Vec3} - Self for chaining.
     * @sdk 11.7.0
     */
    min(v0: Vec3, v1: Vec3): Vec3;
    /**
     * @function
     * @name Vec3#abs
     * @description Calculate the absolute values of every element for this vector.
     * @returns {Vec3} - Self for chaining.
     * @sdk 11.7.0
     */
    abs(): Vec3;
    /**
     * @function
     * @name Vec3#lerp
     * @description Calculates the linear interpolation between two vectors (Factor 0.0 - 1.0).
     * @param {Vec3} v0 - 1st vector.
     * @param {Vec3} v1 - 2nd vector.
     * @param {number} t - Factor will be clamped to 0.0 - 1.0.
     * @param {Vec3} out - output vector.
     * @returns {Vec3} - return output.
     * @static
     * @sdk 11.7.0
     */
    static lerp(v0: Vec3, v1: Vec3, t: number, out?: Vec3): Vec3;
    /**
     * @function
     * @name Vec3#slerp
     * @description Calculates the spherically interpolation between two vector3 (Factor 0.0 - 1.0).
     * @param {Vec3} v0 - 1st vector.
     * @param {Vec3} v1 - 2nd vector.
     * @param {number} t - Factor will be clamped to 0.0 - 1.0.
     * @param {Vec3} out - output vector.
     * @returns {Vec3} - return output.
     * @static
     * @sdk 11.7.0
     */
    static slerp(v0: Vec3, v1: Vec3, t: number, out?: Vec3): Vec3;
    /**
     * @function
     * @name Vec3#distance
     * @description Calculate the distance from this vector to the other.
     * @param {Vec3} other - Other vector.
     * @returns {Vec3} - Returns the distance.
     * @sdk 11.7.0
     */
    distance(other: Vec3): number;
    /**
     * @function
     * @name Vec3#isFinite
     * @description Determine whether this vector is finite.
     * @returns {boolean} - Returns true if it is and false otherwise.
     * @sdk 11.7.0
     */
    isFinite(): boolean;
    /**
     * @function
     * @name Vec3#cross
     * @description Calculates cross product of two vectors.
     * @param {Vec3} v0 - 1st vector.
     * @param {Vec3} v1 - 2nd vector.
     * @returns {Vec3} - Self for chaining.
     * @sdk 11.7.0
     */
    cross(v0: Vec3, v1: Vec3): Vec3;
    /**
     * @function
     * @name Vec3#cross
     * @description Calculates cross product of two vectors.
     * @param {Vec3} v0 - 1st vector.
     * @param {Vec3} v1 - 2nd vector.
     * @param {Vec3} out - output vector. If empty, return the new vector.
     * @returns {Vec3} - Return output vector.
     * @static
     * @sdk 11.7.0
     */
    static cross(v0: Vec3, v1: Vec3, out?: Vec3): Vec3;
    /**
     * @function
     * @name Vec3#reflect
     * @description Calculates then reflect vector from direction vector across the normal vector.
     * @param {Vec3} direction - In direction.
     * @param {Vec3} normal - Normalized normal.
     * @param {Vec3} out - output vector. If empty, return the new vector.
     * @returns {Vec3} - Self for chaining.
     * @static
     * @sdk 11.7.0
     */
    static reflect(direction: Vec3, normal: Vec3, out?: Vec3): Vec3;
    /**
     * @function
     * @name Vec3#toString
     * @description Return current vector value in string.
     * @returns {string} - Current vector value in string.
     * @sdk 11.7.0
     */
    toString(): string;
    /**
     * @function
     * @name Vec3#aboutEq
     * @description Determine if two vector3 are approximately equal.
     * @param {Vec3} v - Other vector.
     * @param {number} epsilon - Epsilon.
     * @returns {boolean} - Returns true if they are approximately equal.
     * @sdk 11.7.0
     */
    aboutEq(v: Vec3, epsilon?: number): boolean;
    /**
     * @function
     * @name Vec3#orthoNormalize
     * @static
     * @description Orthogonally normalize 3 vectors.
     * @param {Vec3} v0 - 1st vector.
     * @param {Vec3} v1 - 2nd vector.
     * @param {Vec3} v2 - 3rd vector.
     * @sdk 11.7.0
     */
    static orthoNormalize(v0: Vec3, v1: Vec3, v2: Vec3): void;
    private rotateTowards;
    /**
     * @function
     * @name Vec3#rotateTowards
     * @description Rotate v0 vector toward v1 vector, store the result to output vector.
     * @param {Vec3} v0 - Vector to be rotated.
     * @param {Vec3} v1 - Target vector to rotate to.
     * @param {number} maxAngle - Max angle of rotation.
     * @param {number} maxLength - Max length of extension.
     * @param {Vec3} out - output vector. If empty, return the new vector.
     * @returns {Vec3} - Returns output vector.
     * @static
     * @sdk 11.7.0
     */
    static rotateTowards(v0: Vec3, v1: Vec3, maxAngle: number, maxLength: number, out?: Vec3): Vec3;
    private moveTowards;
    /**
     * @function
     * @name Vec3#moveTowards
     * @description Rotate v0 vector toward v1 vector, store the result to output vector.
     * @param {Vec3} v0 - Vector to be rotated.
     * @param {Vec3} v1 - Target vector to rotate to.
     * @param {number} maxLength - Max length of extension.
     * @param {Vec3} out - output vector. If empty, return the new vector.
     * @returns {Vec3} - Returns output vector.
     * @static
     * @sdk 11.7.0
     */
    static moveTowards(v0: Vec3, v1: Vec3, maxLength: number, out?: Vec3): Vec3;
}
