import Vector from './vector';
import Amaz = effect.Amaz;
/**
 * @class
 * @category Math
 * @name Vec4
 * @classdesc Class for a 4-dimensional math vector.
 * @description Constructor to create an instance.
 * @param {number} x - x element defaults to 0.
 * @param {number} y - y element defaults to 0.
 * @param {number} z - z element defaults to 0.
 * @param {number} w - w element defaults to 0.
 * @sdk 11.7.0
 */
export default class Vec4 extends Vector {
    constructor();
    constructor(x: number, y: number, z: number, w: number);
    constructor(vec: Amaz.Vector4f);
    static fromNative(nativeVec: Amaz.Vector4f): Vec4;
    /**
     * @function
     * @name Vec4#eq
     * @description Judge whether the value of current Vector4 is equal to other Vector4.
     * @param {Vec4} v0 - A Vector4.
     * @param {Vec4} v1 - Other Vector4.
     * @returns {boolean} - Returns true if the Vector4 are equal and false otherwise.
     * @static
     * @sdk 11.7.0
     */
    static eq(v0: Vec4, v1: Vec4): boolean;
    /**
     * @name Vec4#native
     * @type {Amaz.Vector4f}
     * @description Returns the native data structure of vector4f.
     * @sdk 11.7.0
     */
    get native(): Amaz.Vector4f;
    /**
     * @function
     * @name Vec4#set
     * @description Set new elements to this vector.
     * @param {number} x - x element.
     * @param {number} y - y element.
     * @param {number} z - z element.
     * @param {number} w - w element.
     * @returns {Vec4} - Self for chaining.
     * @sdk 11.7.0
     */
    set(x: number, y: number, z: number, w: number): Vec4;
    /**
     * @name Vec4#x
     * @type {number}
     * @description x element.
     * @sdk 11.7.0
     */
    get x(): number;
    set x(value: number);
    /**
     * @name Vec4#y
     * @type {number}
     * @description y element.
     * @sdk 11.7.0
     */
    get y(): number;
    set y(value: number);
    /**
     * @name Vec4#z
     * @type {number}
     * @description z element.
     * @sdk 11.7.0
     */
    get z(): number;
    set z(value: number);
    /**
     * @name Vec4#w
     * @type {number}
     * @description w element.
     * @sdk 11.7.0
     */
    get w(): number;
    set w(value: number);
    /**
     * @function
     * @name Vec4#copy
     * @description Copy the elements from target to this object.
     * @param {Vec4} target - Target.
     * @returns {Vec4} - Self for chaining.
     * @sdk 11.7.0
     */
    copy(target: Vec4): Vec4;
    /**
     * @function
     * @name Vec4#clone
     * @description Returns an identical copy of this object.
     * @returns {Vec4} The cloned instance.
     * @sdk 11.7.0
     */
    clone(): Vec4;
    /**
     * @function
     * @name Vec4#add
     * @description Add other vector to this vector.
     * @param {Vec4} other - Other vector.
     * @returns {Vec4} - Self for chaining.
     * @sdk 11.7.0
     */
    add(other: Vec4): Vec4;
    /**
     * @function
     * @name Vec4#sub
     * @description Subtract other vector from this vector.
     * @param {Vec4} other - Other vector.
     * @returns {Vec4} - Self for chaining.
     * @sdk 11.7.0
     */
    sub(other: Vec4): Vec4;
    /**
     * @function
     * @name Vec4#mul
     * @description Multiply this vector by scalar or scalar vector.
     * Result: this = this * scalar or this = this * scalarVector.
     * @param {Vec4 | number} scale scalar or scalar vector.
     * @returns {Vec4} Self for chaining.
     * @sdk 11.7.0
     */
    mul(scale: number | Vec4): Vec4;
    /**
     * @function
     * @name Vec4#div
     * @description Divide this vector by divisor or divisor vector.
     * Result: this = this / divisor or this = this / divisorVector.
     * @param {Vec4 | number} divisor divisor or divisor vector.
     * @returns {Vec4} Self for chaining.
     * @sdk 11.7.0
     */
    div(divisor: number | Vec4): Vec4;
    /**
     * @function
     * @name Vec4#eq
     * @description Checks strict equality of this vector and other vector.
     * @param {Vec4} other - Other vector.
     * @returns {boolean} - Returns true if the vectors are equal and false otherwise.
     * @sdk 11.7.0
     */
    eq(other: Vec4): boolean;
    /**
     * @function
     * @name Vec4#neg
     * @description Negates each element of this vector.
     * @returns {Vec4} - Self for chaining.
     * @sdk 11.7.0
     */
    neg(): Vec4;
    /**
     * @function
     * @name Vec4#dot
     * @description Calculate dot product of 2 vectors.
     * @param {Vec4} other - Other vector.
     * @returns {number} - Returns dot product.
     * @sdk 11.7.0
     */
    dot(other: Vec4): number;
    /**
     * @function
     * @name Vec4#lerp
     * @description Calculates the linear interpolation between two vectors (Factor 0.0 - 1.0).
     * @param {Vec4} v0 - 1st vector.
     * @param {Vec4} v1 - 2nd vector.
     * @param {number} t - Factor will be clamped to 0.0 - 1.0.
     * @param {Vec4} out - output vector.
     * @returns {Vec4} - return output vector.
     * @static
     * @sdk 11.7.0
     */
    static lerp(v0: Vec4, v1: Vec4, t: number, out?: Vec4): Vec4;
    /**
     * @function
     * @name Vec4#toString
     * @description Return current vector value in string.
     * @returns {string} - Current vector value in string.
     * @sdk 11.7.0
     */
    toString(): string;
    /**
     * @function
     * @name Vec4#isFinite
     * @description Determine whether this vector is finite.
     * @returns {boolean} - Returns true if it is and false otherwise.
     * @sdk 11.7.0
     */
    isFinite(): boolean;
}
