import Scene from '../scene/scene';
import TouchDevice from './input/touch-device';
import EventHandler from '../base/event-handler';
import Amaz = effect.Amaz;
import CustomAssetRegistry from '../custom-asset/custom-asset-registry';
import PluginRegistry from './plugin/plugin-registry';
import AssetRegistry from './asset/asset-registry';
import AlgorithmRegistry from '../../src/algorithm/algorithm-registry';
import TouchGesture from './input/touch-gesture';
import TouchRespond from '../base/touch-respond';
import AudioFactory from '../../src/audio-controller/audio-factory';
import Analytics from '../analytics/analytics';
import PrefabRegistry from './prefab/prefab-registry';
import { Feature } from '../base/versions';
/**
 * @class
 * @category Core
 * @name Engine
 * @augments EventHandler
 * @classdesc An Engine class represents the entry point for all the rendering
 * capabilities and manages all the modules.
 * @description Constructor to create an engine instance.
 * @param {Element} canvas - The canvas element.
 * @param {object} options - Options to create engine.
 * @param {TouchDevice} [options.touch] - TouchDevice to handle the touch events.
 * @hideconstructor
 * @sdk 9.8.0
 */
/**
 * @name Engine#scene
 * @type {Scene}
 * @description The current scene.
 * @readonly
 * @sdk 9.8.0
 */
/**
 * @name Engine#touch
 * @type {TouchDevice}
 * @description The touch device to handle the touch events.
 * @readonly
 * @sdk 9.8.0
 */
/**
 * @name Engine#prefabs
 * @type {PrefabRegistry}
 * @description The prefab registry to manage prefabs.
 * @readonly
 * @sdk 9.8.0
 */
/**
 * @name Engine#version
 * @type {string}
 * @description Get the current Amazing JS Engine version
 * @readonly
 * @sdk 10.1.0
 */
/**
 * @name Engine#sdkVersion
 * @type {string}
 * @description Get the current Effect SDK version.
 * @readonly
 * @sdk 10.1.0
 */
/**
 * @name Engine#minRequiredSDKVersion
 * @type {string}
 * @description Get the minimum sdk version that JS library depends on
 * @readonly
 * @sdk 10.1.0
 */
export default class Engine extends EventHandler {
    static _engine: Engine | undefined;
    private _scene;
    private _customAssets;
    private _touch;
    private _plugins;
    private _assets;
    private _algorithms;
    private _touchRespond;
    private _touchGesture;
    private _audioFactory;
    private _analytics;
    private _prefabs;
    [key: string]: any;
    static get sdkVersion(): string;
    /**
     * @function
     * @name Engine#getFeatureMinSDKVersion
     * @description Get feature's required minimum SDK version.
     * @param {Feature} feature - A specific feature.
     * @returns {string|undefined} The version string.
     * @sdk 9.8.0
     */
    static getFeatureMinSDKVersion(feature: Feature): string;
    static get minRequiredSDKVersion(): string;
    static get version(): string;
    static get engine(): Engine | undefined;
    static get scene(): Scene;
    static get plugins(): PluginRegistry;
    static get customAssets(): CustomAssetRegistry;
    static get touch(): TouchDevice;
    static get assets(): AssetRegistry;
    static get algorithms(): AlgorithmRegistry;
    static get touchRespond(): TouchRespond | null;
    static get touchGesture(): TouchGesture | null;
    static get audioFactory(): AudioFactory | null;
    static get analytics(): Analytics | null;
    static get prefabs(): PrefabRegistry | undefined;
    static init(scene: Amaz.Scene): void;
    private constructor();
    private initModules;
    /**
     * @function
     * @name Engine#start
     * @description Start the engine. This function does the following:
     * <ul style="list-style: none;">
     * <li>Initialize all the modules and plugins
     * <li>Fires an event named 'start'
     * </ul>
     * @sdk 9.8.0
     */
    static start(): void;
    /**
     * @param deltaTime
     * @function
     * @name Engine#update
     * @description Call update for all modules and plugins.
     * @sdk 9.8.0
     */
    static update(deltaTime: number): void;
    /**
     * @param deltaTime
     * @function
     * @name Engine#lateUpdate
     * @description Call lateUpdate for all modules and plugins.
     * @sdk 9.8.0
     */
    static lateUpdate(deltaTime: number): void;
    /**
     * @function
     * @name Engine#destroy
     * @description Destroy the engine instance and clean up all the resources.
     * @sdk 9.8.0
     */
    static destroy(): void;
    /**
     * @param event
     * @function
     * @name Engine#event
     * @description Call event for all modules and plugins.
     * @sdk 9.8.0
     */
    static event(event: Amaz.Event): void;
}
