import Amaz = effect.Amaz;
import CameraComponent from '../component/camera-component';
import Collider3DComponent from '../component/collider3d-component';
import EventHandler from '../base/event-handler';
import LightComponent from '../component/light-component';
import ModelComponent from '../component/model-component';
import ParticleSystemComponent from '../component/particle-system-component';
import RigidBody3DComponent from '../component/rigidbody3d-component';
import Scene from '../scene/scene';
import ImageComponent from '../component/image-component';
import CanvasComponent from '../component/canvas-component';
import SpriteComponent from '../component/sprite-component';
import SeqAnimationComponent from '../component/seq-animation-component';
import Trigger3DComponent from '../component/trigger3d-component';
import Vec3 from '../math/vec3';
import Quat from '../math/quat';
import ButtonComponent from '../component/button-component';
import UIEventSystemComponent from '../component/ui-event-system-component';
import UIColliderComponent from '../component/ui-collider-component';
import SliderComponent from '../component/slider-component';
import SliderThumbComponent from '../component/slider-thumb-component';
import LabelComponent from '../component/label-component';
import CanvasScalerComponent from '../component/canvas-scaler-component';
import LayoutComponent from '../component/layout-component';
import AlignmentComponent from '../component/alignment-component';
import GenericJoint3DComponent from '../component/generic-joint3d-component';
import AnimationComponent from '../component/animation-component';
import AudioComponent from '../component/audio-component';
import ScreenTransformComponent from '../component/screen-transform-component';
import ScriptComponent from '../component/script-component';
import Component from '../component/component';
import ScreenRaycasterComponent from '../component/screen-raycaster-component';
interface SceneObjectOptions {
    scene?: Scene;
    layer?: number;
    tags?: number[];
}
/**
 * @class
 * @category Core
 * @name SceneObject
 * @augments EventHandler
 * @classdesc An SceneObject class represents a game object.
 * @description Constructor to create an SceneObject instance.
 * @param {string} name - The name of the sceneObject.
 * @param {object} options - Options to create sceneObject.
 * @example
 * // create the SceneObject instance
 * const sceneObject = new amg.SceneObject('newSceneObject', options);
 * @sdk 9.8.0
 */
/**
 * @name SceneObject#scene
 * @type {Scene}
 * @description Scene of the sceneObject.
 * @sdk 9.8.0
 */
export default class SceneObject extends EventHandler {
    native: any;
    scene: Scene | undefined;
    private _transform;
    private _components;
    constructor(name?: string | Scene | undefined, options?: SceneObjectOptions | Amaz.Entity);
    static fromNative(scene: Scene, native: any): SceneObject;
    /**
     * @name SceneObject#name
     * @type {string}
     * @description Name of the sceneObject.
     * @sdk 9.8.0
     */
    get name(): string;
    set name(value: string);
    /**
     * @name SceneObject#parent
     * @type {SceneObject}
     * @description Parent sceneObject.
     * @readonly
     * @sdk 9.8.0
     */
    get parent(): SceneObject | undefined;
    /**
     * @name SceneObject#enabled
     * @type {boolean}
     * @description Enable or disable this sceneObject.
     * @sdk 9.8.0
     */
    get enabled(): boolean;
    set enabled(value: boolean);
    /**
     * @name SceneObject#enabledInScene
     * @type {boolean}
     * @description Check if the sceneObject enabled in scene.
     * @readonly
     * @sdk 9.8.0
     */
    get enabledInScene(): boolean;
    /**
     * @name SceneObject#layer
     * @type {number}
     * @description 0 <= layer < {@link amg.EntityLayerMax}.
     * @sdk 9.8.0
     */
    get layer(): number;
    set layer(value: number);
    /**
     * @name SceneObject#tags
     * @type {number[]}
     * @description SceneObject's tags.
     * Tag is bitwise position, value in range 0 <= tag < {@link amg.EntityTagMax}.
     * @example
     * // Add/remove/check for tag
     * const sceneObject = new amg.SceneObject('newSceneObject', options);
     * sceneObject.addTag(tag);  // tag 0-31
     * if (sceneObject.hasTag(tag)) { console.log('SceneObject has tag'); }
     * // OR
     * const playerTag = 0;
     * const obstacleTag = 1;
     * const isPlayerAndObstacle = playerTag | obstacleTag;
     * const sceneObject = new amg.SceneObject('newSceneObject', {tag: playerTag | obstacleTag});
     * if (sceneObject.hasTag(playerTag)) { console.log('SceneObject has player tag'); }
     * if (sceneObject.hasTag(obstacleTag)) { console.log('SceneObject has obstacle tag'); }
     * if (sceneObject.tags === isPlayerAndObstacle)) { console.log('SceneObject has both player and obstacle tag'); }
     * @sdk 9.8.0
     */
    get tags(): number[];
    set tags(tagArray: number[]);
    /**
     * @name SceneObject#screenTransform
     * @type {ScreenTransformComponent}
     * @description The screen transform component.
     * @readonly
     * @sdk 9.8.0
     */
    get screenTransform(): ScreenTransformComponent | undefined;
    /**
     * @name SceneObject#camera
     * @type {CameraComponent}
     * @description The camera component.
     * @readonly
     * @sdk 9.8.0
     */
    get camera(): CameraComponent | undefined;
    /**
     * @name SceneObject#model
     * @type {ModelComponent}
     * @description The model component.
     * @readonly
     * @sdk 9.8.0
     */
    get model(): ModelComponent | undefined;
    /**
     * @name SceneObject#light
     * @type {LightComponent}
     * @description The light component.
     * @readonly
     * @sdk 9.8.0
     */
    get light(): LightComponent | undefined;
    /**
     * @name SceneObject#rigidBody
     * @type {RigidBody3DComponent}
     * @description The rigid body component.
     * @readonly
     * @sdk 9.8.0
     */
    get rigidBody(): RigidBody3DComponent | undefined;
    /**
     * @name SceneObject#trigger
     * @type {Trigger3DComponent}
     * @description The trigger component.
     * @readonly
     * @sdk 9.8.0
     */
    get trigger(): Trigger3DComponent | undefined;
    /**
     * @name SceneObject#collider
     * @type {Collider3DComponent}
     * @description The collider component.
     * @readonly
     * @sdk 9.8.0
     */
    get collider(): Collider3DComponent | undefined;
    /**
     * @name SceneObject#particleSystem
     * @type {ParticleSystemComponent}
     * @description The particle system component.
     * @readonly
     * @sdk 9.8.0
     */
    get particleSystem(): ParticleSystemComponent | undefined;
    /**
     * @name SceneObject#sprite
     * @type {SpriteComponent}
     * @description The sprite component.
     * @readonly
     * @sdk 9.8.0
     */
    get sprite(): SpriteComponent | undefined;
    /**
     * @name SceneObject#image
     * @type {ImageComponent}
     * @description The image component.
     * @readonly
     * @sdk 9.8.0
     */
    get image(): ImageComponent | undefined;
    /**
     * @name SceneObject#canvas
     * @type {CanvasComponent}
     * @description The canvas component.
     * @readonly
     * @sdk 9.8.0
     */
    get canvas(): CanvasComponent | undefined;
    /**
     * @name SceneObject#canvasScaler
     * @type {CanvasScalerComponent}
     * @description The canvas scaler component.
     * @readonly
     * @sdk 9.8.0
     */
    get canvasScaler(): CanvasScalerComponent | undefined;
    /**
     * @name SceneObject#button
     * @type {ButtonComponent}
     * @description The button component.
     * @readonly
     * @sdk 9.8.0
     */
    get button(): ButtonComponent | undefined;
    /**
     * @name SceneObject#uiEventSystem
     * @type {UIEventSystemComponent}
     * @description The user interface event system component.
     * @readonly
     * @sdk 9.8.0
     */
    get uiEventSystem(): UIEventSystemComponent | undefined;
    /**
     * @name SceneObject#uiCollider
     * @type {UIColliderComponent}
     * @description The user interface collider component.
     * @readonly
     * @sdk 9.8.0
     */
    get uiCollider(): UIColliderComponent | undefined;
    /**
     * @name SceneObject#slider
     * @type {SliderComponent}
     * @description The slider component.
     * @readonly
     * @sdk 9.8.0
     */
    get slider(): SliderComponent | undefined;
    /**
     * @name SceneObject#sliderThumb
     * @type {SliderThumbComponent}
     * @description The slider thumb component.
     * @readonly
     * @sdk 9.8.0
     */
    get sliderThumb(): SliderThumbComponent | undefined;
    /**
     * @name SceneObject#label
     * @type {LabelComponent}
     * @description The label component.
     * @readonly
     * @sdk 9.8.0
     */
    get label(): LabelComponent | undefined;
    /**
     * @name SceneObject#seqAnimation
     * @type {SeqAnimationComponent}
     * @description The sequence animation component.
     * @readonly
     * @sdk 9.8.0
     */
    get seqAnimation(): SeqAnimationComponent | undefined;
    /**
     * @name SceneObject#layout
     * @type {LayoutComponent}
     * @description The layout component.
     * @readonly
     * @sdk 9.8.0
     */
    get layout(): LayoutComponent | undefined;
    /**
     * @name SceneObject#alignment
     * @type {AlignmentComponent}
     * @description The alignment component.
     * @readonly
     * @sdk 9.8.0
     */
    get alignment(): AlignmentComponent | undefined;
    /**
     * @name SceneObject#genericJoint
     * @type {GenericJoint3DComponent}
     * @description The generic joint component.
     * @readonly
     * @sdk 9.8.0
     */
    get genericJoint(): GenericJoint3DComponent | undefined;
    /**
     * @name SceneObject#animation
     * @type {AnimationComponent}
     * @description The animation component.
     * @readonly
     * @sdk 9.8.0
     */
    get animation(): AnimationComponent | undefined;
    /**
     * @name SceneObject#audio
     * @type {AudioComponent}
     * @description The audio component.
     * @readonly
     * @sdk 9.8.0
     */
    get audio(): AudioComponent | undefined;
    /**
     * @name SceneObject#script
     * @type {ScriptComponent}
     * @description The script component.
     * @readonly
     * @sdk 9.9.0
     */
    get script(): ScriptComponent | undefined;
    /**
     * @name SceneObject#screenRaycaster
     * @type {ScreenRaycasterComponent}
     * @description The screen raycaster component.
     * @readonly
     * @sdk 11.0.0
     */
    get screenRaycaster(): ScreenRaycasterComponent | undefined;
    /**
     * @function
     * @name SceneObject#addComponent
     * @description Create a new component and add it to the sceneObject.
     * @param {string} type - Type of the component to add.
     * @param {any} options - Options object to configure the component.
     * @sdk 9.8.0
     */
    addComponent(type: string, options: any): Component | undefined;
    registerComponent(comp: Component | undefined): Component | undefined;
    private _addComponent;
    /**
     * @function
     * @name SceneObject#removeComponent
     * @description Remove component from the sceneObject.
     * @param {string} type - Type of the component to add.
     * @sdk 9.8.0
     */
    removeComponent(type: string): boolean;
    /**
     * @function
     * @name SceneObject#addChild
     * @description Add a new child to this sceneObject and set the parent
     * @param {SceneObject} sceneObject - Child sceneObject to add
     * @sdk 9.8.0
     */
    addChild(sceneObject: SceneObject): void;
    /**
     * @function
     * @name SceneObject#removeChild
     * @description Remove the child from the children list.
     * @param {SceneObject} sceneObject - Child sceneObject to remove.
     * @sdk 9.8.0
     */
    removeChild(sceneObject: SceneObject): void;
    /**
     * @function
     * @name SceneObject#findByName
     * @description Find sceneObject (child and self) by name.
     * @param {string} name - SceneObject's name.
     * @returns {SceneObject} - Found sceneObject.
     * @sdk 9.8.0
     */
    findByName(name: string): SceneObject | undefined;
    /**
     * @function
     * @name SceneObject#findByTag
     * @description Find sceneObject (child and self) by tag.
     * @param {number} tag - SceneObject's tag.
     * @returns {SceneObject} - Found sceneObject.
     * @sdk 9.8.0
     */
    findByTag(tag: number): SceneObject | undefined;
    /**
     * @function
     * @name SceneObject#findAllByName
     * @description Find sceneObjects (child and self) by name.
     * @param {string} name - SceneObject's name.
     * @returns {SceneObject[]} - Found sceneObjects.
     * @sdk 9.8.0
     */
    findAllByName(name: string): SceneObject[];
    /**
     * @function
     * @name SceneObject#findAllByTag
     * @description Find sceneObjects (child and self) by tag.
     * @param {number} tag - SceneObject's tag.
     * @returns {SceneObject[]} - Found sceneObjects.
     * @sdk 9.8.0
     */
    findAllByTag(tag: number): SceneObject[];
    /**
     * @name SceneObject#position
     * @type {Vec3}
     * @description Local position of the sceneObject.
     * @sdk 9.8.0
     */
    get position(): Vec3;
    set position(value: Vec3);
    /**
     * @name SceneObject#scale
     * @type {Vec3}
     * @description Local scale of the sceneObject.
     * @sdk 9.8.0
     */
    get scale(): Vec3;
    set scale(value: Vec3);
    /**
     * @name SceneObject#rotation
     * @type {Vec3}
     * @description Local rotation of the sceneObject in degrees.
     * @sdk 9.8.0
     */
    get rotation(): Vec3;
    set rotation(value: Vec3);
    /**
     * @name SceneObject#rotationQuat
     * @type {Quat}
     * @description Local rotation of the sceneObject in Quat.
     * @sdk 9.8.0
     */
    get rotationQuat(): Quat;
    set rotationQuat(value: Quat);
    /**
     * @name SceneObject#worldPosition
     * @type {Vec3}
     * @description World position of the sceneObject.
     * @sdk 9.8.0
     */
    get worldPosition(): Vec3;
    set worldPosition(value: Vec3);
    /**
     * @name SceneObject#worldScale
     * @type {Vec3}
     * @description World scale of the sceneObject.
     * Notes: this is lossly scale, it is not correct when the child transform has rotation.
     * @sdk 9.8.0
     */
    get worldScale(): Vec3;
    set worldScale(value: Vec3);
    /**
     * @name SceneObject#worldRotation
     * @type {Quat}
     * @description World rotation of the sceneObject.
     * @sdk 9.8.0
     */
    get worldRotation(): Quat;
    set worldRotation(value: Quat);
    /**
     * @name SceneObject#worldEulerAngles
     * @type {Vec3}
     * @description World eular angles of the sceneObject in degrees.
     * @sdk 9.8.0
     */
    get worldEulerAngles(): Vec3;
    set worldEulerAngles(value: Vec3);
    /**
     * @function
     * @name SceneObject#addTag
     * @description Add tag for sceneObject.
     * @param {number} tag - 0 <= tag < {@link amg.EntityTagMax}.
     * @sdk 9.8.0
     */
    addTag(tag: number): void;
    /**
     * @function
     * @name SceneObject#hasTag
     * @description Check if sceneObject has a tag number.
     * @param {number} tag - 0 <= tag < {@link amg.EntityTagMax}.
     * @returns {boolean} True if sceneObject has tag, False if sceneObject does not has tag.
     * @sdk 9.8.0
     */
    hasTag(tag: number): boolean;
    /**
     * @function
     * @name SceneObject#destroy
     * @description Destroy and clean up the sceneObject.
     * @sdk 9.8.0
     */
    destroy(): void;
    /**
     * @name SceneObject#children
     * @type {SceneObject[]}
     * @description SceneObject's children.
     * @sdk 9.8.0
     */
    get children(): SceneObject[];
    getComponentFromNative(native: Amaz.Component): Component | undefined;
    /**
     * @function
     * @name SceneObject#getComponent
     * @description Get the component instance with the specified component class.
     * @param {string} type - Any component class.
     * @returns {Component|undefined} The component instance.
     * @sdk 9.8.0
     */
    getComponent(type: string): Component | undefined;
    /**
     * @function
     * @name SceneObject#getComponents
     * @description Get all the component instances with the specified component class.
     * @param {string} type - Any component class.
     * @returns {Component[]} The component instances.
     * @sdk 9.8.0
     */
    getComponents(type: string): Array<Component>;
    /**
     * @function
     * @name SceneObject#hasComponent
     * @description Check if the sceneObject has the specified component class.
     * @param {string} type - Any component class.
     * @returns {boolean} True if there is, otherwise false.
     * @sdk 9.8.0
     */
    hasComponent(type: string): boolean;
    /**
     * @function
     * @param type
     * @name SceneObject#findByComponent
     * @description Find sceneObject (child and self) by component class.
     * @param {any} string - Any component class.
     * @returns {SceneObject} - The qualified sceneObject.
     * @sdk 9.8.0
     */
    findByComponent(type: string): SceneObject | undefined;
    /**
     * @function
     * @param type
     * @name SceneObject#findAllByComponent
     * @description Find sceneObject (child and self) by component class.
     * @param {any} string - Any component class.
     * @returns {SceneObject[]} - The qualified sceneObjects.
     * @sdk 9.8.0
     */
    findAllByComponent(type: string): SceneObject[];
}
export {};
