import Amaz = effect.Amaz;
/**
 * @class
 * @category Utils
 * @name State
 * @classdesc Plain old-school state matching to sceneObject/component behavior.
 * @description Constructor to create State object.
 * @param {string} name - Unique identifier for state.
 * @param {object} context - Any info you'd like to use in behavior under that state.
 * @example
 * // create the state
 * const state = new amg.State('Stand', scene)
 */
export declare class State {
    private _context;
    private _name;
    constructor(name: string, context: object);
    /**
     * @function
     * @name State#equals
     * @returns {boolean} equals of two states.
     * @description Check if two states are equal by comparing their name/uid.
     * @param {State} state - the state to compare.
     */
    equals(state: State): boolean;
    /**
     * @name State#name
     * @type {string}
     * @description The uid or name of state. [read only]
     */
    get name(): string;
    /**
     * @name State#context
     * @type {object}
     * @description The context needed for state to work. [read only]
     */
    get context(): object;
    /**
     * @function
     * @name State#onEnter
     * @description The job when entering this state.
     */
    onEnter(): void;
    /**
     * @function
     * @name State#onExit
     * @description The job when entering this state.
     */
    onExit(): void;
    /**
     * @function
     * @name State#onUpdate
     * @description The job when updating under this state.
     * @param {number} _deltaTime - The deltaTime between updates.
     */
    onUpdate(_deltaTime: number): void;
    /**
     * @function
     * @name State#onEvent
     * @description Handle event under this state.
     * @param {Amaz.Event} _event - The Amaz.Event from engine.
     */
    onEvent(_event: Amaz.Event): void;
    /**
     * @function
     * @name State#toString
     * @returns {string} This state's name.
     * @description Print State into string e.g. "[name]".
     */
    toString(): string;
}
/**
 * @class
 * @category Utils
 * @name StateMachine
 * @classdesc StateMachine that simply keep registration of all states.
 * @description Constructor to create an StateMachine instance.
 * @example
 * // create the statemachine instance
 * const stateMachine = new amg.StateMachine();
 *
 * // register your state
 * stateMachine.registerState(myState);
 */
declare class StateMachine {
    protected _registeredStates: Map<string, State>;
    /**
     * @function
     * @name StateMachine#setState
     * @description Set the state as current in statemachine.
     * @param {string} _name - name/uid of the state.
     */
    setState(_name: string): void;
    /**
     * @function
     * @name StateMachine#removeState
     * @description Remove the state from current in statemachine.
     * @param {string} _name - name/uid of the state.
     */
    removeState(_name: string): void;
    /**
     * @function
     * @name StateMachine#onUpdate
     * @description State machine update.
     * @param {number} _deltaTime - The deltaTime between updates.
     */
    onUpdate(_deltaTime: number): void;
    /**
     * @function
     * @name StateMachine#onEvent
     * @description Handle event.
     * @param {Amaz.Event} _event - The Amaz.Event from engine.
     */
    onEvent(_event: Amaz.Event): void;
    /**
     * @function
     * @name StateMachine#registerState
     * @description Register the state so that you can later use it with name/uid.
     * @param {State} state - State object.
     */
    registerState(state: State): void;
}
/**
 * @class
 * @category Utils
 * @name MultiToggleStateMachine
 * @augments StateMachine
 * @classdesc Multiple binary state or toggle mode machine. You can set multiple binary
 * state/toggle in it.
 * @description Constructor to create an MultiToggleStateMachine instance.
 * @example
 * // create the MultiToggleStateMachine instance
 * const mtsm = new amg.MultiToggleStateMachine();
 *
 * // register your state
 * mtsm.registerState(myState);
 *
 */
export declare class MultiToggleStateMachine extends StateMachine {
    private _currentStates;
    /**
     * @function
     * @name MultiToggleStateMachine#onUpdate
     * @description State machine update.
     * @param {number} deltaTime - The deltaTime between updates.
     */
    onUpdate(deltaTime: number): void;
    /**
     * @function
     * @name MultiToggleStateMachine#onEvent
     * @description Handle event.
     * @param {Amaz.Event} event - The Amaz.Event from engine.
     */
    onEvent(event: Amaz.Event): void;
    /**
     * @function
     * @name MultiToggleStateMachine#setState
     * @description Set the state as current in statemachine. Allows multiple states at the same time.
     * @param {string} name - name/uid of the state.
     */
    setState(name: string): void;
    /**
     * @function
     * @name MultiToggleStateMachine#removeState
     * @description Remove the state from current in statemachine.
     * @param {string} name - name/uid of the state.
     */
    removeState(name: string): void;
}
/**
 * @class
 * @category Utils
 * @name FiniteStateMachine
 * @augments StateMachine
 * @classdesc Old school finite state machine that only allows one state and
 * keep transitions (edges of state graph).
 * @description Constructor to create an FiniteStateMachine instance.
 * @example
 * // create the FSM instance
 * const fsm = new amg.FiniteStateMachine();
 *
 * // register your state
 * mtsm.registerState(myState);
 *
 */
export declare class FiniteStateMachine extends StateMachine {
    private _currentState;
    private _transitions;
    /**
     * @function
     * @name FiniteStateMachine#addTransition
     * @description Add transition link from one state to another.
     * @param {number} from - The previous state.
     * @param {number} to - The next state.
     */
    addTransition(from: string, to: string): void;
    /**
     * @function
     * @name FiniteStateMachine#isValidTransition
     * @description Check if transition link from one state to another is valid.
     * @param {number} from - The previous state.
     * @param {number} to - The next state.
     * @returns {boolean} Return if transition is valid.
     */
    isValidTransition(from: string, to: string): boolean;
    /**
     * @function
     * @name FiniteStateMachine#setState
     * @description Setting the state means switching the state, and only do it when
     * transition exists.
     * @param {string} name - name/uid of the state.
     */
    setState(name: string): void;
    /**
     * @function
     * @name FiniteStateMachine#removeState
     * @description Remove the state or back to dummy state. Not for FSM.
     * @param {string} name - name/uid of the state.
     */
    removeState(name: string): void;
    /**
     * @function
     * @name FiniteStateMachine#onUpdate
     * @description State machine update.
     * @param {number} deltaTime - The deltaTime between updates.
     */
    onUpdate(deltaTime: number): void;
    /**
     * @function
     * @name FiniteStateMachine#onEvent
     * @description Handle event.
     * @param {Amaz.Event} event - The Amaz.Event from engine.
     */
    onEvent(event: Amaz.Event): void;
}
export {};
